.JobCancelButton{cursor:pointer;font-family:"Open Sans",sans-serif;font-size:20px;font-weight:600;line-height:0;text-decoration:none;vertical-align:middle}
.job-table__data-retention .job-table__table{border:none}.job-table__data-retention .table>thead>tr>th,.job-table__data-retention .table>tbody>tr>th,.job-table__data-retention .table>tfoot>tr>th,.job-table__data-retention .table>thead>tr>td,.job-table__data-retention .table>tbody>tr>td,.job-table__data-retention .table>tfoot>tr>td{border-top:none}.job-table__data-retention .table>thead>tr>th{border-bottom:1px solid rgba(var(--sys-center-channel-color-rgb), 0.16)}.job-table__data-retention .help-text{padding:10px 16px;background:rgba(var(--sys-center-channel-color-rgb), 0.04);color:var(--sys-center-channel-color)}.job-table__data-retention .cancel-button-field{width:30px}
.config-section{margin-top:20px;background:#fff;border-radius:4px}.config-section .admin-console__wrapper{padding:0}.config-section .section-header{padding:24px 32px;border-bottom:1px solid rgba(61,60,64,.08)}.config-section .section-header .section-title{font-size:16px;font-weight:bold}.config-section .section-header .section-subtitle{font-size:14px}.config-section .section-body{padding:28px 32px}.config-section:nth-child(1){margin-top:0}
.TrueUpReview__card{width:100%;height:"463px";border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08);background-color:var(--sys-center-channel-bg);border-radius:4px;box-shadow:var(--elevation-1);color:var(--sys-center-channel-color)}.TrueUpReview__cardHeader{display:flex;align-items:center;padding:28px 32px 24px 32px;border-bottom:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08)}.TrueUpReview__cardHeaderText-top{font-size:16px;font-weight:600;line-height:24px}.TrueUpReview__cardBody{display:flex;flex-direction:column;padding:20px}.TrueUpReview__cardBody>*{margin-bottom:10px}.TrueUpReview__cardBody>svg{margin-left:15px}.TrueUpReview__dueDate :first-child{color:rgba(var(--sys-center-channel-color-rgb), 0.64)}.TrueUpReview__warning{color:var(--warning-text);font-size:24px}.TrueUpReview__submit{font-weight:600}.TrueUpReview__submit--error{background:rgba(var(--button-bg-rgb), 0.16) !important;color:var(--button-bg) !important;font-weight:600}
.CloudFetchError{display:flex;flex-direction:column;align-items:center;padding:10px;border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08);background-color:var(--sys-center-channel-bg);border-radius:4px;box-shadow:0 2px 3px rgba(0,0,0,.08);color:var(--sys-center-channel-color);text-align:center}.CloudFetchError__header{padding-bottom:10px;font-size:16px;line-height:24px}
.style-button{width:fit-content;padding:8px 16px;border:none;background-color:var(--button-bg);border-radius:4px;color:var(--button-color);font-size:12px;font-weight:600;line-height:16px}.style-button span{color:var(--button-color)}.style-button i{color:var(--button-color);font-size:14px}.style-button:hover:not(.disabled){background:linear-gradient(0deg, rgba(var(--center-channel-color-rgb), 0.16), rgba(var(--center-channel-color-rgb), 0.16)),var(--button-bg);color:var(--button-color);text-decoration:none}.style-link{display:inline-block;min-width:fit-content;border:none;background:none;color:var(--sidebar-bg)}.style-link:hover:not(.disabled){border:none;background:none;color:var(--sidebar-bg);text-decoration:underline}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.upgradeLink{position:relative;display:inline-flex;align-items:center;justify-content:center;border:0;background:var(--button-bg);border-radius:4px;color:var(--button-color);font-weight:600;transition:all .15s ease-out;height:40px;padding:0 20px;font-size:14px;line-height:14px}.upgradeLink:hover{background:linear-gradient(0deg, rgba(0, 0, 0, 0.08), rgba(0, 0, 0, 0.08)),var(--button-bg)}.upgradeLink:active{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}.upgradeLink:focus{box-sizing:border-box;border:2px solid var(--sidebar-text-active-border);outline:none}.upgradeLink:disabled:not(.always-show-enabled){background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.upgradeLink i{display:flex;font-size:18px}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.LimitReachedBanner__actions{padding-top:12px}.LimitReachedBanner__primary{font-size:12px;position:relative;display:inline-flex;align-items:center;justify-content:center;border:0;background:var(--button-bg);border-radius:4px;color:var(--button-color);font-weight:600;transition:all .15s ease-out}.LimitReachedBanner__primary:hover{background:linear-gradient(0deg, rgba(0, 0, 0, 0.08), rgba(0, 0, 0, 0.08)),var(--button-bg)}.LimitReachedBanner__primary:active{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}.LimitReachedBanner__primary:focus{box-sizing:border-box;border:2px solid var(--sidebar-text-active-border);outline:none}.LimitReachedBanner__primary:disabled:not(.always-show-enabled){background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.LimitReachedBanner__primary i{display:flex;font-size:18px}.LimitReachedBanner__primary:hover{color:var(--button-color)}.LimitReachedBanner__contact-sales{margin-left:4px;font-size:12px;display:inline-flex;align-items:center;border:0;background:rgba(var(--button-bg-rgb), 0.08);border-radius:4px;color:var(--button-bg);font-weight:600;transition:all .15s ease-out}.LimitReachedBanner__contact-sales:disabled{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32)}.LimitReachedBanner__contact-sales:hover:enabled{background:rgba(var(--button-bg-rgb), 0.12)}.LimitReachedBanner__contact-sales:active:enabled{background:rgba(var(--button-bg-rgb), 0.16)}.LimitReachedBanner__contact-sales i{display:flex;font-size:18px}.LimitReachedBanner__contact-sales i:first-child::before{margin:0 7px 0 0}.LimitReachedBanner__contact-sales i:last-child::before{margin:0 0 0 7px}.LimitReachedBanner__contact-sales:hover{color:var(--button-bg)}
.ProductLimitCard{width:208px;flex:0 0 auto;padding:22px 0 42px 16px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);margin-right:8px;border-radius:4px}.ProductLimitCard--full-width{width:auto;padding-right:16px;margin-right:0}.ProductLimitCard:last-child{margin-right:0}.ProductLimitCard__name{padding-bottom:8px;font-size:12px;font-weight:600}.ProductLimitCard__name i::before{margin-left:0}.ProductLimitCard__status{padding-bottom:8px;color:rgba(var(--center-channel-color-rgb), 0.72);font-size:12px}.ProductLimitCard__status--exceeded{color:var(--dnd-indicator);font-weight:600}.ProductLimitCard__status--exceeded .icon{margin-right:8px;font-size:12px;font-weight:400}.ProductLimitCard__status--exceeded .icon::before{margin:0}
.ProductLimitsPanel{padding:32px 54px 18px 32px;border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08);margin-top:20px;background-color:var(--sys-center-channel-bg);border-radius:4px;box-shadow:0 2px 3px rgba(0,0,0,.08)}.ProductLimitsPanel--left-panel{max-width:568px;padding:24px 32px}.ProductLimitsPanel--single-panel{padding:24px calc(100% - 536px) 24px 32px}.ProductLimitsPanel__title{font-size:16px;font-weight:600;line-height:24px;padding-bottom:8px}.ProductLimitsPanel__description{padding-bottom:16px;font-size:14px}.ProductLimitsPanel__limits{display:flex}.ProductLimitsPanel__actions{padding-top:20px}.ProductLimitsPanel__actions--single{padding-top:30px}.ProductLimitsPanel .btn{padding:11px 16px;margin-right:8px;background:#166de0;border-radius:4px;color:#fff;font-size:12px;font-weight:bold;line-height:9.5px}.ProductLimitsPanel .btn:focus,.ProductLimitsPanel .btn:active,.ProductLimitsPanel .btn:focus:active{border-color:rgba(0,0,0,0);outline:none}.ProductLimitsPanel .btn.btn-secondary{background:rgba(var(--denim-button-bg-rgb), 0.08);color:var(--denim-button-bg)}.ProductLimitsPanel__contact-link{font-weight:bold}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.UpsellCard__illustration{text-align:center}.UpsellCard__illustration svg{margin:0 auto}.UpsellCard__title{margin:10px 0;color:var(--center-channel-color);font-family:Metropolis;font-size:16px;font-weight:700;line-height:24px}.UpsellCard__advantages{margin:7px 0;font-size:12px;line-height:16px}.UpsellCard__advantages .advantage{margin:12px 0}.UpsellCard__advantages .advantage i{margin-right:7px}.UpsellCard__advantages .advantage--more{color:rgba(63,69,80,.72)}.UpsellCard__cta{position:relative;display:inline-flex;align-items:center;justify-content:center;border:1px solid var(--denim-button-bg);background:var(--center-channel-bg);border-radius:4px;color:var(--button-bg);font-weight:600;transition:all .15s ease-out;width:fit-content;padding:13px 20px;border:1px solid var(--denim-button-bg) !important;border:none;background:var(--sys-center-channel-bg);font-size:14px;font-weight:600;line-height:14px}.UpsellCard__cta:hover{background:rgba(var(--denim-button-bg-rgb), 0.08)}.UpsellCard__cta:active{background:rgba(var(--denim-button-bg-rgb), 0.16)}.UpsellCard__cta:focus{box-sizing:border-box;border:2px solid var(--sidebar-text-active-border);outline:none}.UpsellCard__cta:disabled{border:rgba(var(--center-channel-color-rgb), 0.32);color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.UpsellCard__cta i{display:flex;font-size:18px}.UpsellCard__cta.btn-primary{position:relative;display:inline-flex;align-items:center;justify-content:center;border:0;background:var(--button-bg);border-radius:4px;color:var(--button-color);font-weight:600;transition:all .15s ease-out;width:100%}.UpsellCard__cta.btn-primary:hover{background:linear-gradient(0deg, rgba(0, 0, 0, 0.08), rgba(0, 0, 0, 0.08)),var(--button-bg)}.UpsellCard__cta.btn-primary:active{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}.UpsellCard__cta.btn-primary:focus{box-sizing:border-box;border:2px solid var(--sidebar-text-active-border);outline:none}.UpsellCard__cta.btn-primary:disabled:not(.always-show-enabled){background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.UpsellCard__cta.btn-primary i{display:flex;font-size:18px}.UpsellCard .disclaimer{margin:5px 0;color:rgba(var(--center-channel-color-rgb), 0.72);font-size:10px;font-style:normal;font-weight:400;letter-spacing:.02em;line-height:14px;text-align:justify}
.BillingSummary{width:332px;padding:28px 32px;border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08);margin-left:20px;background-color:var(--sys-center-channel-bg);border-radius:4px;box-shadow:0 2px 3px rgba(0,0,0,.08)}.BillingSummary__noBillingHistory{display:flex;flex-direction:column;align-items:flex-start;justify-content:flex-start}.BillingSummary__noBillingHistory-title{margin-top:32px;font-size:16px;font-weight:600;line-height:24px}.BillingSummary__noBillingHistory-message{margin-top:8px;color:var(--sys-center-channel-color);font-size:14px;line-height:20px}.BillingSummary__noBillingHistory-link{margin-top:16px;margin-bottom:24px;color:var(--sys-button-bg);font-size:12px;font-weight:600}.BillingSummary__lastInvoice{color:var(--sys-center-channel-color)}.BillingSummary__lastInvoice hr{border-color:rgba(var(--sys-center-channel-color-rgb), 0.32);margin:12px 0}.BillingSummary__lastInvoice-header{display:flex;align-items:center}.BillingSummary__lastInvoice-headerTitle{font-size:20px;font-weight:600;line-height:28px}.BillingSummary__lastInvoice-headerStatus{display:flex;align-items:center;margin-left:auto;font-size:12px;font-weight:600;line-height:16px}.BillingSummary__lastInvoice-headerStatus.paid{color:var(--sys-online-indicator)}.BillingSummary__lastInvoice-headerStatus.failed{color:var(--sys-error-text)}.BillingSummary__lastInvoice-headerStatus.pending{color:rgba(var(--sys-center-channel-color-rgb), 0.48)}.BillingSummary__lastInvoice-headerStatus svg{width:16px;height:16px;margin-left:4px;font-size:14.4px}.BillingSummary__lastInvoice-headerStatus svg::before{margin:0 auto}.BillingSummary__lastInvoice-headerStatus span{margin-left:4px}.BillingSummary__lastInvoice-date{margin-top:8px;color:rgba(var(--sys-center-channel-color-rgb), 0.72)}.BillingSummary__lastInvoice-productName{margin-top:32px;font-size:16px;font-weight:600;line-height:24px}.BillingSummary__lastInvoice-charge{display:flex;margin:12px 0}.BillingSummary__lastInvoice-charge.total{font-weight:600}.BillingSummary__lastInvoice-hasMoreItems{display:flex;align-items:center;color:#166de0}.BillingSummary__lastInvoice-hasMoreItems .BillingSummary__lastInvoice-chargeDescription:hover{cursor:pointer;text-decoration:underline}.BillingSummary__lastInvoice-chargeAmount{margin-left:auto}.BillingSummary__lastInvoice-partialCharges{color:rgba(var(--sys-center-channel-color-rgb), 0.56);font-size:12px;line-height:16px}.BillingSummary__lastInvoice-partialCharges+.BillingSummary__lastInvoice-charge{margin-top:4px}.BillingSummary__lastInvoice-download{margin-top:32px;margin-bottom:16px}.BillingSummary__lastInvoice-downloadButton{display:flex;width:100%;align-items:center;justify-content:center;padding:11px 20px;background:var(--sys-button-bg);border-radius:4px;color:var(--sys-button-color)}.BillingSummary__lastInvoice-downloadButton:hover:not(.disabled){background:linear-gradient(0deg, rgba(var(--sys-center-channel-color-rgb), 0.16), rgba(var(--sys-center-channel-color-rgb), 0.16)),var(--sys-button-bg);color:var(--sys-button-color);text-decoration:none}.BillingSummary__lastInvoice-downloadButton:active{background:linear-gradient(0deg, rgba(var(--sys-center-channel-color-rgb), 0.32), rgba(var(--sys-center-channel-color-rgb), 0.32)),var(--sys-button-bg);color:var(--sys-button-color);text-decoration:none}.BillingSummary__lastInvoice-downloadButton:focus{box-shadow:inset 0 0 0 2px var(--sys-sidebar-text-active-border);color:var(--sys-button-color);text-decoration:none}.BillingSummary__lastInvoice-downloadButton.disabled{background:rgba(var(--sys-center-channel-color-rgb), 0.08);color:rgba(var(--sys-center-channel-color-rgb), 0.32)}.BillingSummary__lastInvoice-downloadButton>i{font-size:18px;line-height:21px}.BillingSummary__lastInvoice-downloadButton>i::before{margin:0}.BillingSummary__lastInvoice-downloadButton>span{margin-left:6px;font-size:14px;font-weight:600;line-height:14px}.BillingSummary__lastInvoice-billingHistory{display:block;font-size:12px;font-weight:600;line-height:9.5px;text-align:center}
.PlanDetailsFeature{margin-top:12px;color:var(--sys-center-channel-color);line-height:16px}.PlanDetailsFeature i{font-size:14.4px}.PlanDetailsFeature i::before{margin:0}.PlanDetailsFeature span{margin-left:8px;font-size:12px}
.PlanDetails{width:568px;padding:28px 32px;border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08);background:var(--sys-center-channel-bg);border-radius:4px;box-shadow:0 2px 3px rgba(0,0,0,.08)}.PlanDetails__top{display:flex;align-items:center}.PlanDetails__productName{color:var(--sys-center-channel-color);font-size:16px;font-weight:600;line-height:24px}.PlanDetails__userCount{display:block;margin-left:auto;color:rgba(var(--sys-center-channel-color-rgb), 0.56);font-size:14px;font-weight:600;line-height:20px}.PlanDetails__viewPlansButton{display:block;margin-left:auto}.PlanDetails__viewPlansButton.btn{padding:11px 16px;background:#166de0;border-radius:4px;color:#fff;font-size:12px;font-weight:bold;line-height:9.5px}.PlanDetails__viewPlansButton.btn:focus,.PlanDetails__viewPlansButton.btn:active,.PlanDetails__viewPlansButton.btn:focus:active{border-color:rgba(0,0,0,0);outline:none}.PlanDetails__viewPlansButton.btn.btn-secondary{background:rgba(var(--denim-button-bg-rgb), 0.08);color:var(--denim-button-bg)}.PlanDetails__planName{font-size:32px;font-weight:600;line-height:32px}.PlanDetails__teamAndChannelCount{margin-top:24px;color:var(--sys-center-channel-color);font-size:12px;font-weight:600;line-height:16px}.PlanDetails__description{display:flex;margin-top:8px;color:rgba(var(--sys-center-channel-color-rgb), 0.56);font-size:12px;font-weight:normal;line-height:16px}.PlanDetails__description .PlanDetails__planDetailsName{font-size:12px;font-weight:600}.PlanDetails__description a{color:var(--sys-sidebar-text-active-border)}.PlanDetails__description a::before{content:" "}.PlanDetails__currentPlan{display:flex;align-items:center;margin-top:24px;color:var(--sys-online-indicator)}.PlanDetails__currentPlan i{font-size:18px;line-height:21px}.PlanDetails__currentPlan i::before{margin:0}.PlanDetails__currentPlan span{margin-left:8px;font-size:14px;font-weight:600;line-height:14px}.TrialBadge{padding:0 4px;margin-left:10px;background:var(--sys-online-indicator);border-radius:3px;color:#fff;text-transform:uppercase}.TrialBadge span{font-size:10px;font-weight:600;letter-spacing:.02em;line-height:16px}.RecurringIntervalBadge{display:inline-block;height:16px;margin-left:12px;text-transform:uppercase}.RecurringIntervalBadge span{position:relative;bottom:2px;color:rgba(var(--center-channel-text-rgb), 0.56);font-family:"Open Sans";font-size:10px;font-weight:600;letter-spacing:.02em;line-height:16px}
.PlanPricing{display:flex;align-items:flex-end;margin-top:16px;color:var(--sys-center-channel-color)}.PlanPricing__paid-tier{color:rgba(var(--sys-center-channel-color-rgb), 0.56);font-size:12px;font-style:normal;font-weight:normal;line-height:16px}.PlanPricing__paid-tier a{margin-left:5px}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.BillingSubscriptions .BillingSubscriptions__topWrapper{display:flex}.BillingSubscriptions .AlertBanner{margin-bottom:20px}#BillingSubscriptions__seatOverageTooltip{margin-left:-5px}.BillingSubscriptions__tooltip.tooltip{font-family:"Open Sans",sans-serif}.BillingSubscriptions__tooltip.tooltip.bottom{padding:10px 0}.BillingSubscriptions__tooltip.tooltip.in{opacity:1}.BillingSubscriptions__tooltip.tooltip.BillingSubscriptions__tooltip-left .tooltip-inner{left:40%}.BillingSubscriptions__tooltip.tooltip.BillingSubscriptions__tooltip-right .tooltip-inner{right:90%}.BillingSubscriptions__tooltip.tooltip .tooltip-inner{position:relative;min-width:337px;max-width:none;padding:24px;border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08);background-color:var(--sys-center-channel-bg);border-radius:4px;box-shadow:0 12px 32px rgba(0,0,0,.12);color:var(--sys-center-channel-color);opacity:1;text-align:left}.BillingSubscriptions__tooltip.tooltip .tooltip-arrow{z-index:2;border-width:0 11px 11px;border-bottom-color:rgba(var(--sys-center-channel-color-rgb), 0.08)}.BillingSubscriptions__tooltip.tooltip .tooltip-arrow::before{position:relative;top:-10px;left:-11px;display:block;width:0;height:0;border:11px solid rgba(0,0,0,0);border-bottom-color:var(--sys-center-channel-bg);content:""}.BillingSubscriptions__tooltipTitle{font-size:16px;font-weight:600;line-height:24px}.BillingSubscriptions__tooltipMessage{margin-top:8px;font-size:14px;line-height:20px}.UpgradeMattermostCloud{text-align:center}.UpgradeMattermostCloud__image{flex:0 0 auto}.UpgradeMattermostCloud__title{align-self:flex-start;margin-top:16px;color:var(--sys-center-channel-color);font-size:16px;font-weight:600;line-height:24px;text-align:left}.UpgradeMattermostCloud__description{margin-top:12px;color:var(--sys-center-channel-color);font-size:14px;line-height:20px;text-align:left}.UpgradeMattermostCloud__upgradeButton{width:100%;padding:13px 0;border:none;margin-top:16px;background:var(--button-bg);border-radius:4px;box-shadow:inset 0 0 0 1px var(--sys-button-bg);color:var(--button-color);font-size:14px;font-weight:600;line-height:14px}.UpgradeMattermostCloud__upgradeButton:hover:not(.disabled){background:linear-gradient(0deg, rgba(var(--center-channel-color-rgb), 0.16), rgba(var(--center-channel-color-rgb), 0.16)),var(--button-bg)}.UpgradeMattermostCloud__upgradeButton:active{background:linear-gradient(0deg, rgba(var(--center-channel-color-rgb), 0.32), rgba(var(--center-channel-color-rgb), 0.32)),var(--button-bg)}.UpgradeMattermostCloud__upgradeButton:focus{box-shadow:inset 0 0 0 2px var(--sidebar-text-active-border)}.UpgradeMattermostCloud__upgradeButton.disabled{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32)}.PrivateCloudCard{padding:32px 54px 18px 32px;border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08);margin-top:20px;background-color:var(--sys-center-channel-bg);border-radius:4px;box-shadow:0 2px 3px rgba(0,0,0,.08);display:flex}.PrivateCloudCard .UpgradeMattermostCloud__upgradeButton{max-width:200px}.PrivateCloudCard__text{max-width:563px;flex-grow:1;color:var(--sys-center-channel-color)}.PrivateCloudCard__text-title{font-size:16px;font-weight:600;line-height:24px}.PrivateCloudCard__text-description{margin-top:12px;font-size:14px;line-height:20px}.PrivateCloudCard__image{flex:0 0 173px;margin-left:85px}.PrivateCloudCard__actionButton{display:block;width:fit-content;width:-moz-fit-content;padding:13px 20px;border:none;margin-top:16px;background:var(--sys-center-channel-bg);border-radius:4px;box-shadow:inset 0 0 0 1px var(--sys-button-bg);color:var(--sys-button-bg);font-size:14px;font-weight:600;line-height:14px}.PrivateCloudCard__actionButton:hover:not(.disabled){background:rgba(var(--sys-button-bg-rgb), 0.04);text-decoration:none}.PrivateCloudCard__actionButton:active{background:rgba(var(--sys-button-bg-rgb), 0.08);text-decoration:none}.PrivateCloudCard__actionButton:focus{box-shadow:inset 0 0 0 2px var(--sys-button-bg);text-decoration:none}.cancelSubscriptionSection{display:flex;padding:12px 54px 18px 32px;margin-top:20px}.cancelSubscriptionSection__text{flex-grow:1;color:var(--sys-center-channel-color)}.cancelSubscriptionSection__text-title{font-size:12px;font-weight:600;line-height:16px}.cancelSubscriptionSection__text-description{margin-top:12px;font-size:12px;font-weight:400;line-height:16px}.cancelSubscriptionSection__contactUs{display:block;width:fit-content;width:-moz-fit-content;padding:13px 20px;margin-top:16px;border-radius:4px;box-shadow:inset 0 0 0 1px var(--sys-dnd-indicator);color:var(--sys-dnd-indicator);font-size:12px;font-weight:600;line-height:9.5px}.cancelSubscriptionSection__contactUs:hover:not(.disabled){background:rgba(var(--sys-dnd-indicator-rgb), 0.04);color:var(--sys-dnd-indicator);text-decoration:none}.cancelSubscriptionSection__contactUs:active{background:rgba(var(--sys-dnd-indicator-rgb), 0.08);text-decoration:none}.cancelSubscriptionSection__contactUs:focus{box-shadow:inset 0 0 0 2px var(--sys-dnd-indicator);color:var(--sys-dnd-indicator);text-decoration:none}
.CompanyInfoDisplay{border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08);background-color:var(--sys-center-channel-bg);border-radius:4px;box-shadow:0 2px 3px rgba(0,0,0,.08);color:var(--sys-center-channel-color)}.CompanyInfoDisplay__header{display:flex;align-items:center;padding:28px 32px 24px 32px;border-bottom:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08)}.CompanyInfoDisplay__headerText-top{font-size:16px;font-weight:600;line-height:24px}.CompanyInfoDisplay__headerText-bottom{font-size:14px;line-height:20px}.CompanyInfoDisplay__addInfo{margin-left:auto}.CompanyInfoDisplay__addInfoButton{display:flex;align-items:center;padding:8px 16px;background:var(--sys-button-bg);border-radius:4px;color:var(--sys-button-color)}.CompanyInfoDisplay__addInfoButton:hover:not(.disabled){background:linear-gradient(0deg, rgba(var(--sys-center-channel-color-rgb), 0.16), rgba(var(--sys-center-channel-color-rgb), 0.16)),var(--sys-button-bg);color:var(--sys-button-color);text-decoration:none}.CompanyInfoDisplay__addInfoButton:active{background:linear-gradient(0deg, rgba(var(--sys-center-channel-color-rgb), 0.32), rgba(var(--sys-center-channel-color-rgb), 0.32)),var(--sys-button-bg);color:var(--sys-button-color);text-decoration:none}.CompanyInfoDisplay__addInfoButton:focus{box-shadow:inset 0 0 0 2px var(--sys-sidebar-text-active-border);color:var(--sys-button-color);text-decoration:none}.CompanyInfoDisplay__addInfoButton.disabled{background:rgba(var(--sys-center-channel-color-rgb), 0.08);color:rgba(var(--sys-center-channel-color-rgb), 0.32)}.CompanyInfoDisplay__addInfoButton>i{font-size:14.4px;line-height:17px}.CompanyInfoDisplay__addInfoButton>i::before{margin:0}.CompanyInfoDisplay__addInfoButton>span{margin-left:4px;font-size:12px;font-weight:600;line-height:9px}.CompanyInfoDisplay__noCompanyInfo{display:flex;flex-direction:column;align-items:center;padding:48px}.CompanyInfoDisplay__noCompanyInfo-message{margin-top:24px;color:var(--sys-center-channel-color);font-size:14px;line-height:20px}.CompanyInfoDisplay__noCompanyInfo-link{margin-top:20px;margin-bottom:12px;color:var(--sys-button-bg);font-size:14px;font-weight:600;line-height:14px}.CompanyInfoDisplay__companyInfo{display:flex;padding:28px 45px 30px 32px;color:var(--sys-center-channel-color);font-size:14px;line-height:20px}.CompanyInfoDisplay__companyInfo-name{font-weight:600}.CompanyInfoDisplay__companyInfo-addressTitle{margin-top:16px;font-weight:600}.CompanyInfoDisplay__companyInfo-address>div{margin-top:4px}.CompanyInfoDisplay__companyInfo-edit{margin-left:auto}.CompanyInfoDisplay__companyInfo-editButton{padding:2px;border-radius:4px;color:rgba(var(--sys-center-channel-color-rgb), 0.56);font-size:18px}.CompanyInfoDisplay__companyInfo-editButton:hover,.CompanyInfoDisplay__companyInfo-editButton:focus{background:rgba(var(--sys-center-channel-color-rgb), 0.08);color:rgba(var(--sys-center-channel-color-rgb), 0.72);text-decoration:none}
.CompanyInfoEdit__card{padding:28px 32px;border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08);margin-top:20px;background-color:var(--sys-center-channel-bg);border-radius:4px;box-shadow:0 2px 3px rgba(0,0,0,.08);isolation:isolate}.CompanyInfoEdit__card .checkbox{margin-top:0;margin-bottom:24px}.CompanyInfoEdit__card .checkbox input{width:16px;height:16px;margin-top:2px}.CompanyInfoEdit__card .checkbox span{padding-left:4px}.CompanyInfoEdit__card .form-row{display:flex;width:100%;margin-bottom:24px}.CompanyInfoEdit__card .form-row-third-1{width:66%;margin-right:16px}.CompanyInfoEdit__card .form-row-third-1 .DropdownInput{z-index:99999;margin-top:0}.CompanyInfoEdit__card .form-row-third-2{width:34%}.CompanyInfoEdit__card .section-title{margin-bottom:24px;color:var(--sys-center-channel-text);font-size:16px;font-weight:600;text-align:left}.CompanyInfoEdit__card .section-title:not(:first-child){font-size:14px;line-height:20px}.CompanyInfoEdit__card .DropdownInput{position:relative;z-index:999999;height:36px;margin-bottom:24px}.CompanyInfoEdit__card .DropdownInput .DropDown__control{min-height:0}.CompanyInfoEdit__card .full-width{width:100%}.CompanyInfoEdit__card input{font-size:14px}.CompanyInfoEdit__card .Input_fieldset{height:40px;padding:2px 1px;background:var(--sys-center-channel-bg)}.CompanyInfoEdit__card .Input_fieldset .Input_wrapper{margin:0}.CompanyInfoEdit__card .Input_fieldset.Input_fieldset___legend>legend{margin-left:11px}.CompanyInfoEdit__card .Input_fieldset.Input_fieldset:focus-within{padding-top:2px;box-shadow:inset 0 0 0 2px var(--sys-button-bg);color:var(--button-bg)}.CompanyInfoEdit__card .Input_fieldset.Input_fieldset___error{padding-top:1px;padding-bottom:1px;box-shadow:inset 0 0 0 1px var(--sys-error-text);color:var(--error-text)}.CompanyInfoEdit__card .Input_fieldset.Input_fieldset___error:focus-within{box-shadow:inset 0 0 0 2px var(--sys-error-text);color:var(--error-text)}.CompanyInfoEdit__card .Input_fieldset .Input{height:32px}.CompanyInfoEdit__card .Input_fieldset .Input::placeholder{color:var(--sys-center-channel-color);opacity:.64}.CompanyInfoEdit__form{max-width:480px}.CompanyInfoEdit__companyInfo-addressTitle{margin-top:16px;font-weight:600}.CompanyInfoEdit__companyInfo-address>div{margin-top:4px}
.PaymentInfoDisplay{border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08);background-color:var(--sys-center-channel-bg);border-radius:4px;box-shadow:0 2px 3px rgba(0,0,0,.08);color:var(--sys-center-channel-color)}.PaymentInfoDisplay__header{display:flex;align-items:center;padding:28px 32px 24px 32px;border-bottom:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08)}.PaymentInfoDisplay__headerText-top{font-size:16px;font-weight:600;line-height:24px}.PaymentInfoDisplay__headerText-bottom{font-size:14px;line-height:20px}.PaymentInfoDisplay__addInfo{margin-left:auto}.PaymentInfoDisplay__addInfoButton{display:flex;align-items:center;padding:8px 16px;background:var(--sys-button-bg);border-radius:4px;color:var(--sys-button-color)}.PaymentInfoDisplay__addInfoButton:hover:not(.disabled){background:linear-gradient(0deg, rgba(var(--sys-center-channel-color-rgb), 0.16), rgba(var(--sys-center-channel-color-rgb), 0.16)),var(--sys-button-bg);color:var(--sys-button-color);text-decoration:none}.PaymentInfoDisplay__addInfoButton:active{background:linear-gradient(0deg, rgba(var(--sys-center-channel-color-rgb), 0.32), rgba(var(--sys-center-channel-color-rgb), 0.32)),var(--sys-button-bg);color:var(--sys-button-color);text-decoration:none}.PaymentInfoDisplay__addInfoButton:focus{box-shadow:inset 0 0 0 2px var(--sys-sidebar-text-active-border);color:var(--sys-button-color);text-decoration:none}.PaymentInfoDisplay__addInfoButton.disabled{background:rgba(var(--sys-center-channel-color-rgb), 0.08);color:rgba(var(--sys-center-channel-color-rgb), 0.32)}.PaymentInfoDisplay__addInfoButton>i{font-size:14.4px;line-height:17px}.PaymentInfoDisplay__addInfoButton>i::before{margin:0}.PaymentInfoDisplay__addInfoButton>span{margin-left:4px;font-size:12px;font-weight:600;line-height:9px}.PaymentInfoDisplay__noPaymentInfo{display:flex;flex-direction:column;align-items:center;padding:48px}.PaymentInfoDisplay__noPaymentInfo-message{margin-top:24px;color:var(--sys-center-channel-color);font-size:14px;line-height:20px}.PaymentInfoDisplay__noPaymentInfo-link{margin-top:20px;margin-bottom:12px;color:var(--sys-button-bg);font-size:14px;font-weight:600;line-height:14px}.PaymentInfoDisplay__paymentInfo{display:flex;padding:28px 45px 30px 32px;color:var(--sys-center-channel-color);font-size:14px;line-height:20px}.PaymentInfoDisplay__paymentInfo .CardImage{max-width:55px;max-height:37px}.PaymentInfoDisplay__paymentInfo-name{font-weight:600}.PaymentInfoDisplay__paymentInfo-addressTitle{margin-top:16px;font-weight:600}.PaymentInfoDisplay__paymentInfo-address>div{margin-top:4px}.PaymentInfoDisplay__paymentInfo-edit{margin-left:auto}.PaymentInfoDisplay__paymentInfo-editButton{padding:2px;margin-left:12px;border-radius:4px;color:rgba(var(--sys-center-channel-color-rgb), 0.56);font-size:18px}.PaymentInfoDisplay__paymentInfo-editButton:hover,.PaymentInfoDisplay__paymentInfo-editButton:focus{background:rgba(var(--sys-center-channel-color-rgb), 0.08);color:rgba(var(--sys-center-channel-color-rgb), 0.72);text-decoration:none}.PaymentInfoDisplay__paymentInfo-cardInfo::first-letter{text-transform:capitalize}
.PaymentInfo .AlertBanner{margin-bottom:20px}
.PaymentInfoEdit__card{padding:28px 32px;border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08);margin-top:20px;background-color:var(--sys-center-channel-bg);border-radius:4px;box-shadow:0 2px 3px rgba(0,0,0,.08)}.PaymentInfoEdit__paymentForm{max-width:480px;padding:0;margin:0}.PaymentInfoEdit__paymentForm .section-title:not(:first-child){font-size:14px;line-height:20px}.PaymentInfoEdit__paymentForm .section-title{color:var(--sys-center-channel-text)}.PaymentInfoEdit__paymentForm .Input_fieldset{background:var(--sys-center-channel-bg)}.PaymentInfoEdit__paymentForm.Input_fieldset:focus-within{box-shadow:inset 0 0 0 2px var(--sys-button-bg)}.PaymentInfoEdit__paymentForm.Input_fieldset___error{box-shadow:inset 0 0 0 1px var(--sys-error-text);color:var(--sys-error-text)}.PaymentInfoEdit__paymentForm.Input_fieldset___error:focus-within{box-shadow:inset 0 0 0 2px var(--sys-error-text);color:var(--sys-error-text)}.PaymentInfoEdit__paymentForm .Input::placeholder{color:var(--sys-center-channel-color)}.PaymentInfoEdit__error{display:flex;align-items:center;color:var(--sys-error-text);font-size:12px}.PaymentInfoEdit__error i{margin-right:4px;font-size:14.4px}
.DataGrid{width:100%;padding:2rem 2rem 2rem 2rem;background:#f5f5f5;color:var(--sys-center-channel-color)}.DataGrid .DataGrid_search{display:flex;height:48px;flex-direction:row;padding:.5em 0;border-bottom:solid 1px rgba(0,0,0,.1);background:#fff;font-weight:bold}.DataGrid .DataGrid_search .DataGrid_searchBar{position:relative;display:flex;width:300px;height:32px;box-sizing:border-box;border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.2);margin-left:8px;border-radius:4px}.DataGrid .DataGrid_search .DataGrid_searchBar input{width:100%;border:0;margin-right:16px;margin-left:32px;font-size:.95em}.DataGrid .DataGrid_search .DataGrid_searchBar input:focus{outline:none}.DataGrid .DataGrid_search .DataGrid_searchBar .DataGrid_searchIcon{position:absolute;top:5px;left:10px;color:rgba(0,0,0,.5);pointer-events:none}.DataGrid .DataGrid_search .DataGrid_searchBar .DataGrid_clearButton{display:flex;align-items:center;margin-right:5px}.DataGrid .DataGrid_header{display:flex;flex-direction:row;padding:.5em 0;border-bottom:solid 1px rgba(0,0,0,.1);color:rgba(0,0,0,.87);font-size:1.1em;font-weight:bold}.DataGrid .DataGrid_rows{display:flex;flex-direction:column;background:rgba(var(--sys-button-color-rgb), 0.5)}.DataGrid .DataGrid_rows .DataGrid_loading{padding-top:20px;padding-bottom:20px;margin:auto;color:rgba(0,0,0,.3);font-size:1.6rem}.DataGrid .DataGrid_rows .DataGrid_empty{width:100%;padding-top:20px;padding-bottom:20px;color:rgba(0,0,0,.3);font-size:1.6rem;text-align:center}.DataGrid .DataGrid_rows .DataGrid_row{border-left:2px solid rgba(0,0,0,0)}.DataGrid .DataGrid_rows .DataGrid_row:nth-child(odd){background-color:#f5f5f5}.DataGrid .DataGrid_rows .DataGrid_row:hover{border-left:2px solid #166de0;background-color:#e0ecfc}.DataGrid .DataGrid_rows .DataGrid_row .DataGrid_cell{overflow:hidden;margin:auto;text-overflow:ellipsis;white-space:nowrap}.DataGrid .DataGrid_rows .DataGrid_row .DataGrid_cell .more-modal__shared-actions{color:rgba(61,60,64,.72)}.DataGrid .DataGrid_rows .DataGrid_row .DataGrid_cell .more-modal__shared-actions .shared-user-icon{width:16px;height:16px;margin-left:8px;font-size:16px;line-height:16px}.DataGrid .DataGrid_rows .DataGrid_row .DataGrid_cell .more-modal__shared-actions .shared-user-icon::before{margin:0}.DataGrid .DataGrid_row,.DataGrid .DataGrid_header{display:flex;height:auto;flex-direction:row;padding-left:18px}.DataGrid .DataGrid_row .DataGrid_cell,.DataGrid .DataGrid_header .DataGrid_cell{flex:1 0}.DataGrid .DataGrid_footer{display:flex;height:auto;flex-direction:row;padding:8px;border-top:solid 1px rgba(0,0,0,.1);border-bottom:solid 1px rgba(0,0,0,.1);background:#fff;color:rgba(0,0,0,.5);font-size:1.1em;text-align:right}.DataGrid .DataGrid_footer .DataGrid_cell{width:100%;text-align:right}.DataGrid.customTable{padding:0;background:#fff}.DataGrid.customTable .DataGrid_header{padding:8px 0;border-bottom:1px solid rgba(var(--sys-center-channel-color-rgb), 0.16);color:var(--sys-center-channel-color);font-size:14px;font-weight:600;line-height:16px}.DataGrid.customTable .DataGrid_header:last-child{border-bottom:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08)}.DataGrid.customTable .DataGrid_header .DataGrid_cell{padding:0 16px}.DataGrid.customTable .DataGrid_row{display:flex;min-height:40px;flex-direction:row;padding:0;border-left:none}.DataGrid.customTable .DataGrid_row:nth-child(odd){background:#fff}.DataGrid.customTable .DataGrid_row:nth-child(even){background:rgba(var(--sys-button-bg-rgb), 0.04)}.DataGrid.customTable .DataGrid_row:hover{border-left:none;background-color:rgba(var(--sys-button-bg-rgb), 0.08);color:var(--sys-center-channel-color);cursor:pointer}.DataGrid.customTable .DataGrid_row .actionIcon{width:32px}.DataGrid.customTable .DataGrid_row .actionIcon .MenuWrapper{width:32px;margin-left:auto}.DataGrid.customTable .DataGrid_row .actionIcon a i{display:none}.DataGrid.customTable .DataGrid_row .actionIcon a{display:flex;width:32px;height:32px;flex-direction:column;align-items:center;padding:8px;margin-left:auto;background:rgba(0,0,0,0);border-radius:4px;color:rgba(var(--sys-center-channel-color-rgb), 0.72);text-decoration:none}.DataGrid.customTable .DataGrid_row:hover .actionIcon a i{display:flex}.DataGrid.customTable .DataGrid_row .actionIcon a:hover{background:rgba(var(--sys-center-channel-color-rgb), 0.08)}.DataGrid.customTable .DataGrid_row .DataGrid_cell{padding:10px 16px;margin:0;white-space:normal}.DataGrid.customTable .DataGrid_row .DataGrid_cell.actionIcon{overflow:visible;padding:4px 16px}.DataGrid.customTable .DataGrid_footer{border-bottom:none}
.Filter{position:relative;display:inline-block;padding-left:8px}.Filter .Filter_button{width:auto;height:32px;padding:0 10px;border:0;background:var(--sys-center-channel-bg);border-radius:4px;color:var(--sys-button-bg);font-size:12px}.Filter .Filter_button.Filter__active,.Filter .Filter_button:focus{background:rgba(var(--sys-button-bg-rgb), 0.12)}.Filter .Filter_button:hover{background:rgba(var(--sys-button-bg-rgb), 0.06)}.Filter .Icon{margin-right:2px;font-size:14px}.Filter .Filter_content{position:absolute;z-index:1;display:none;min-width:256px;box-sizing:border-box;padding:16px;border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08);margin-top:4px;margin-bottom:24px;background:var(--sys-center-channel-bg);border-radius:4px;box-shadow:0 8px 24px rgba(0,0,0,.12)}.Filter .Filter_content.Filter__show{display:block}.Filter .Filter_content hr{padding:0;margin:8px -16px 8px -16px;color:rgba(var(--sys-center-channel-color-rgb), 0.08)}.Filter .Filter_header{display:flex;flex-direction:row;justify-content:space-between}.Filter .Filter_header .Filter_title{padding:8px;color:var(--sys-center-channel-color);font-size:14px;font-weight:bold;line-height:14px}.Filter .Filter_header .Filter_reset{padding:8px;font-size:12px;line-height:16px}.Filter .Filter_lists{white-space:nowrap}.Filter .Filter_apply{float:right}.Filter .FilterList{display:inline-block;width:160px;padding:8px;font-size:14px;vertical-align:top}.Filter .FilterList.FilterList__full{display:block;width:100%}.Filter .FilterList .FilterList_name{padding-bottom:12px;color:rgba(var(--sys-center-channel-color-rgb), 0.5);font-size:12px;font-weight:600}.Filter .FilterList .filterListSelect__control{min-height:32px;border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.16);background:var(--sys-center-channel-bg);border-radius:4px;color:rgba(var(--sys-center-channel-color-rgb), 0.64);font-size:12px}.Filter .FilterList .filterListSelect__control:hover{border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.48)}.Filter .FilterList .filterListSelect__option{background:var(--sys-center-channel-bg);color:rgba(var(--sys-center-channel-color-rgb), 0.8);cursor:pointer;font-size:12px}.Filter .FilterList .filterListSelect__option:hover{background:rgba(var(--sys-center-channel-color-rgb), 0.08)}.Filter .FilterList .filterListSelect__indicator{padding:9px;color:rgba(var(--sys-center-channel-color-rgb), 0.56);cursor:pointer}.Filter .FilterList .filterListSelect__indicator>svg{width:14px;height:14px}.Filter .FilterList .filterListSelect__indicator-separator{background-color:rgba(var(--sys-center-channel-color-rgb), 0.16)}.Filter .FilterList .filterListSelect__multi-value__remove:hover{background-color:rgba(var(--center-channel-color-rgb), 0.16);color:inherit;cursor:pointer}.Filter .FilterList .FilterList_checkbox{color:rgba(var(--sys-center-channel-color-rgb), 0.8)}.Filter .FilterList .FilterList_checkbox input{position:relative;top:-4px;margin:0 8px 0 2px;opacity:.64;vertical-align:bottom}.Filter .FilterList .FilterList_checkbox input:checked{opacity:1}.Filter .FilterList .FilterList_checkbox label{font-weight:normal}
.Card{border:1px solid rgba(var(--center-channel-color-rgb), 0.08);background-color:var(--center-channel-bg);border-radius:4px;box-shadow:0 2px 3px rgba(0,0,0,.08);transition:box-shadow .3s ease-in-out}.Card+.Card{margin-top:16px}.Card.expanded{box-shadow:0 8px 24px rgba(0,0,0,.12)}.Card:not(.expanded):hover{border-color:rgba(var(--center-channel-color-rgb), 0.16);box-shadow:0 4px 6px rgba(0,0,0,.12);transition-duration:.15s}.Card.console{width:100%;border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08);margin-bottom:20px;background-color:var(--sys-center-channel-bg);border-radius:2px;box-shadow:0 2px 3px rgba(0,0,0,.08);color:var(--sys-center-channel-color)}.Card.console .Card__header{display:flex;align-items:center;padding:28px 32px 24px 32px;border-bottom:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08)}.Card.console .Card__header .text-top{font-size:16px;font-weight:600;line-height:24px}.Card.console .Card__header .text-bottom{margin-right:24px;font-size:14px;line-height:20px}.Card.console .Card__header .content-button{height:32px;padding:10px 16px;border:none;margin-left:auto;border-radius:4px;font-size:12px;font-weight:600;line-height:9.5px;white-space:nowrap}.Card.console .Card__header .content-button.primary{background:var(--sys-button-bg);color:var(--sys-button-color)}.Card.console .Card__header .Card__hr{display:none}.Card.console .Card__body{overflow:visible}.Card.console .Card__body.expanding{transition:none}.Card.console .Card__body.expanded{margin:28px 32px}.Card__header hr.Card__hr{border-color:rgba(var(--center-channel-color-rgb), 0.08);margin:0 12px}.Card__body{overflow:hidden;height:0;margin:0 12px}.Card__body.expanding{transition-duration:.3s;transition-property:height,margin;transition-timing-function:ease-in-out}.Card__body.expanded{margin:12px}.Card__body.expanded:not(.expanding){height:auto}@media screen and (max-width: 768px){.Card+.Card{margin-top:12px}}
.DataRetentionSettings .JobSelectTime{display:inline-block;width:80px;margin:-10px 8px -10px}.DataRetentionSettings span.JobSelectedtime{margin:0 8px}.DataRetentionSettings .datagrid-menuwrapper{z-index:999999}.DataRetentionSettings a.EditJobTime{font-weight:600;opacity:1}.DataRetentionSettings .actionIcon{flex-grow:.15}.DataRetentionSettings input:-webkit-autofill,.DataRetentionSettings input:-webkit-autofill:hover,.DataRetentionSettings input:-webkit-autofill:focus,.DataRetentionSettings input:-webkit-autofill:active{-webkit-box-shadow:0 0 0 30px var(--sys-center-channel-bg) inset}
.PolicyChannelsList .ChannelList__nameColumn{display:inline-flex;align-items:center;justify-content:center}.PolicyChannelsList .ChannelList__nameColumn span.channel-icon{margin:3px 8px 0 0}.PolicyChannelsList .Filter_content.Filter__show{width:320px}.PolicyChannelsList .FilterList{width:auto}
.PolicyTeamsList .TeamList__nameColumn{display:inline-flex;align-items:center;justify-content:center;padding:20px 0}.PolicyTeamsList .TeamList__nameColumn .TeamList__lowerOpacity .TeamIcon{background-color:rgba(var(--sys-center-channel-color-rgb), 0.16)}.PolicyTeamsList .TeamList__nameColumn .TeamList__nameText{padding-left:12px}.PolicyTeamsList .TeamList__actionColumn{display:inline-flex;align-items:center;justify-content:flex-end}
.DropdownInput.hybrid_container{z-index:999999;margin-top:20px}.DropdownInput.hybrid_container .Input_wrapper{padding:0;margin:0}.DropdownInput.hybrid_container .Input_wrapper.input_hybrid_wrapper{display:inline-block;flex-grow:1;transition:max-width .1s ease-out}.DropdownInput.hybrid_container .Input_wrapper.input_hybrid_wrapper.showInput{transition:max-width .1s ease-in}.DropdownInput.hybrid_container .Input_wrapper.dropdown_hybrid_wrapper{display:inline-block}.DropdownInput.hybrid_container .Input_wrapper.dropdown_hybrid_wrapper.showInput{float:right;transition:width .1s ease-out}.DropdownInput.hybrid_container .Input{font-size:14px;line-height:20px}.DropdownInput.hybrid_container .Input.Input___focus .a11y--focused{box-shadow:none}.DropdownInput.hybrid_container .Input_fieldset{position:relative;display:flex;padding:0}.DropdownInput.hybrid_container .Input_legend{position:absolute;z-index:1;top:-8px;width:auto;padding:0 5px;border-bottom:none;margin-bottom:0;margin-left:8px;font-size:10px}.DropdownInput.hybrid_container .DropDown__menu{z-index:1000000;margin-top:2px}.DropdownInput.hybrid_container .DropdownInput__indicatorsContainer{margin-right:8px}.DropdownInput.hybrid_container .DropdownInput__indicatorsContainer i{color:rgba(var(--center-channel-color-rgb), 0.64);font-weight:normal}.DropdownInput.hybrid_container .DropdownInput__indicatorsContainer i::before{margin:0}.DropdownInput.hybrid_container .DropdownInput__option>div{z-index:999999;padding:10px 24px;cursor:pointer;line-height:16px}.DropdownInput.hybrid_container .DropdownInput__option.selected>div{background-color:rgba(var(--button-bg-rgb), 0.08);color:var(--center-channel-color)}.DropdownInput.hybrid_container .DropdownInput__option.focused>div{background-color:rgba(var(--center-channel-color-rgb), 0.08)}.DropdownInput.hybrid_container .Input_fieldset:focus-within{border-width:2px;box-shadow:none}.DropdownInput.hybrid_container .Input.form-control{height:40px;border:none;border-right:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px 0 0 4px}.DropdownInput.hybrid_container .Input.form-control::-webkit-outer-spin-button,.DropdownInput.hybrid_container .Input.form-control::-webkit-inner-spin-button{margin:0;-webkit-appearance:none}.DropdownInput.hybrid_container .Input.form-control[type=number]{-moz-appearance:textfield}.DropdownInput.hybrid_container .Input.form-control:focus{border-right:1px solid rgba(var(--center-channel-color-rgb), 0.16)}
.CustomPolicy__fields{width:100%}@media screen and (min-width: 960px){.CustomPolicy__fields{width:50%}}.CustomPolicy__fields .DropdownInput .Input.form-control{padding:6px 12px}.CustomPolicy__fields i.icon.icon-infinity.option-icon{vertical-align:middle}.CustomPolicy__fields .Input{color:var(--sys-center-channel-color)}.CustomPolicy__fields .Input_wrapper,.CustomPolicy__fields .Input___info{color:rgba(var(--sys-center-channel-color-rgb), 0.56)}.CustomPolicy__fields .Input::placeholder{color:rgba(var(--sys-center-channel-color-rgb), 0.64)}.CustomPolicy__fields .Input_fieldset{border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.16)}.CustomPolicy__fields .Input_fieldset:hover{border-color:rgba(var(--sys-center-channel-color-rgb), 0.48)}.CustomPolicy__fields .Input_fieldset:focus-within{border-color:var(--sys-button-bg);box-shadow:inset 0 0 0 1px var(--sys-button-bg);color:var(--sys-button-bg)}.CustomPolicy__fields .Input_fieldset:focus-within .Input_legend{color:var(--sys-button-bg)}.CustomPolicy__fields .Input_legend{background-color:var(--sys-center-channel-bg);color:rgba(var(--sys-center-channel-color-rgb), 0.64)}.CustomPolicy__error{display:flex;align-items:center;color:var(--sys-error-text);font-size:12px;line-height:16px}.CustomPolicy__error i{margin-right:4px;font-size:14.4px}
.global_policy{width:100%}@media screen and (min-width: 960px){.global_policy{width:50%}}.global_policy .Input.form-control{padding:6px 12px}.global_policy i.icon.icon-infinity.option-icon{vertical-align:middle}.global_policy .Input{color:var(--sys-center-channel-color)}.global_policy .Input_wrapper,.global_policy .Input___info{color:rgba(var(--sys-center-channel-color-rgb), 0.56)}.global_policy .Input::placeholder{color:rgba(var(--sys-center-channel-color-rgb), 0.64)}.global_policy .Input_fieldset{border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.16)}.global_policy .Input_fieldset:hover{border-color:rgba(var(--sys-center-channel-color-rgb), 0.48)}.global_policy .Input_fieldset:focus-within{border-color:var(--sys-button-bg);box-shadow:inset 0 0 0 1px var(--sys-button-bg);color:var(--sys-button-bg)}.global_policy .Input_fieldset:focus-within .Input_legend{color:var(--sys-button-bg)}.global_policy .Input_legend{background-color:var(--sys-center-channel-bg);color:rgba(var(--sys-center-channel-color-rgb), 0.64)}.global_policy .alert.alert-warning{margin-top:10px}.CustomPolicy__error{display:flex;align-items:center;color:var(--sys-error-text);font-size:12px;line-height:16px}.CustomPolicy__error i{margin-right:4px;font-size:14.4px}
.migrations-table__table{overflow:auto;width:100%;min-height:100px;max-height:240px;padding:5px;border:gray;margin:20px 0 10px;background-color:#fff}.migrations-table .table>thead>tr>th,.migrations-table .table>tbody>tr>th,.migrations-table .table>tfoot>tr>th,.migrations-table .table>thead>tr>td,.migrations-table .table>tbody>tr>td,.migrations-table .table>tfoot>tr>td{border-top:none}.migrations-table .table>thead>tr>th{border-bottom:1px solid rgba(var(--sys-center-channel-color-rgb), 0.16)}.migrations-table .help-text{padding:10px 16px;background:rgba(var(--sys-center-channel-color-rgb), 0.04);color:var(--sys-center-channel-color)}
.contact-us{display:block;padding:12px 20px;border:1px solid var(--sys-button-bg);margin-top:15px;margin-left:10px;background-color:var(--sys-center-channel-bg);border-radius:4px;color:var(--sys-button-bg)}.contact-us span{font-size:14px;font-weight:600;line-height:14px}
.FeatureDiscovery{display:grid;padding:20px;background:#fff;border-radius:8px;box-shadow:0 2px 3px rgba(0,0,0,.08);font-family:Open Sans;font-style:normal;font-weight:normal;grid-template-columns:repeat(auto-fit, minmax(440px, 1fr))}.FeatureDiscovery_imageWrapper{display:flex;align-items:center;justify-content:center}.FeatureDiscovery_copyWrapper,.FeatureDiscovery_imageWrapper{padding:20px;grid-template-columns:repeat(2, 1fr)}.FeatureDiscovery_image{height:220px}.FeatureDiscovery_title{padding-bottom:24px;font-family:Metropolis,sans-serif;font-size:24px;line-height:32px}.FeatureDiscovery_copy{padding-bottom:24px;font-size:14px;line-height:20px}.FeatureDiscovery .btn{width:160px;height:48px;padding:14px 0;margin-right:8px;background:#166de0;border-radius:4px;color:#fff;font-size:16px;font-weight:400;line-height:16px}.FeatureDiscovery .btn:focus,.FeatureDiscovery .btn:active,.FeatureDiscovery .btn:focus:active{border-color:rgba(0,0,0,0);outline:none}.FeatureDiscovery .btn:disabled{border-color:rgba(0,0,0,0);background:rgba(0,0,0,.15);color:rgba(0,0,0,.5)}.FeatureDiscovery .btn.btn-inactive{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.56)}.FeatureDiscovery .btn.btn-secondary{border:1px solid #166de0;background:#fff;color:#166de0}.FeatureDiscovery .btn.btn-primary{width:190px}
.d-flex{display:-webkit-box !important;display:-ms-flexbox !important;display:flex !important}.flex-col{flex-direction:column}.flex-1{flex:1}.align-items-center{align-items:center !important;-webkit-box-align:center !important;-ms-flex-align:center !important}.col{max-width:100%;flex-basis:0;flex-grow:1;-ms-flex-positive:1;-ms-flex-preferred-size:0}.flex-auto{flex:0 0 auto}.flex-wrap{flex-wrap:wrap}@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}@keyframes spin{from{transform:scale(1) rotate(0deg)}to{transform:scale(1) rotate(360deg)}}@keyframes highlight{from{background:rgba(255,255,0,.5)}to{background:none}}@keyframes fadeInOpacity{0%{opacity:0}100%{opacity:1}}.pt-0{padding-top:0px !important}.pb-0{padding-bottom:0px !important}.pl-0{padding-left:0px !important}.pr-0{padding-right:0px !important}.mt-0{margin-top:0px !important}.mb-0{margin-bottom:0px !important}.ml-0{margin-left:0px !important}.mr-0{margin-right:0px !important}.m-0{margin:0px !important}.p-0{padding:0px !important}.px-0{padding:0 0px 0 0px !important}.py-0{padding:0px 0 0px 0 !important}.h-0{height:0px !important}.pt-1{padding-top:4px !important}.pb-1{padding-bottom:4px !important}.pl-1{padding-left:4px !important}.pr-1{padding-right:4px !important}.mt-1{margin-top:4px !important}.mb-1{margin-bottom:4px !important}.ml-1{margin-left:4px !important}.mr-1{margin-right:4px !important}.m-1{margin:4px !important}.p-1{padding:4px !important}.px-1{padding:0 4px 0 4px !important}.py-1{padding:4px 0 4px 0 !important}.h-1{height:4px !important}.pt-2{padding-top:8px !important}.pb-2{padding-bottom:8px !important}.pl-2{padding-left:8px !important}.pr-2{padding-right:8px !important}.mt-2{margin-top:8px !important}.mb-2{margin-bottom:8px !important}.ml-2{margin-left:8px !important}.mr-2{margin-right:8px !important}.m-2{margin:8px !important}.p-2{padding:8px !important}.px-2{padding:0 8px 0 8px !important}.py-2{padding:8px 0 8px 0 !important}.h-2{height:8px !important}.pt-3{padding-top:12px !important}.pb-3{padding-bottom:12px !important}.pl-3{padding-left:12px !important}.pr-3{padding-right:12px !important}.mt-3{margin-top:12px !important}.mb-3{margin-bottom:12px !important}.ml-3{margin-left:12px !important}.mr-3{margin-right:12px !important}.m-3{margin:12px !important}.p-3{padding:12px !important}.px-3{padding:0 12px 0 12px !important}.py-3{padding:12px 0 12px 0 !important}.h-3{height:12px !important}.pt-4{padding-top:16px !important}.pb-4{padding-bottom:16px !important}.pl-4{padding-left:16px !important}.pr-4{padding-right:16px !important}.mt-4{margin-top:16px !important}.mb-4{margin-bottom:16px !important}.ml-4{margin-left:16px !important}.mr-4{margin-right:16px !important}.m-4{margin:16px !important}.p-4{padding:16px !important}.px-4{padding:0 16px 0 16px !important}.py-4{padding:16px 0 16px 0 !important}.h-4{height:16px !important}.pt-5{padding-top:20px !important}.pb-5{padding-bottom:20px !important}.pl-5{padding-left:20px !important}.pr-5{padding-right:20px !important}.mt-5{margin-top:20px !important}.mb-5{margin-bottom:20px !important}.ml-5{margin-left:20px !important}.mr-5{margin-right:20px !important}.m-5{margin:20px !important}.p-5{padding:20px !important}.px-5{padding:0 20px 0 20px !important}.py-5{padding:20px 0 20px 0 !important}.h-5{height:20px !important}.pt-6{padding-top:24px !important}.pb-6{padding-bottom:24px !important}.pl-6{padding-left:24px !important}.pr-6{padding-right:24px !important}.mt-6{margin-top:24px !important}.mb-6{margin-bottom:24px !important}.ml-6{margin-left:24px !important}.mr-6{margin-right:24px !important}.m-6{margin:24px !important}.p-6{padding:24px !important}.px-6{padding:0 24px 0 24px !important}.py-6{padding:24px 0 24px 0 !important}.h-6{height:24px !important}.pt-7{padding-top:28px !important}.pb-7{padding-bottom:28px !important}.pl-7{padding-left:28px !important}.pr-7{padding-right:28px !important}.mt-7{margin-top:28px !important}.mb-7{margin-bottom:28px !important}.ml-7{margin-left:28px !important}.mr-7{margin-right:28px !important}.m-7{margin:28px !important}.p-7{padding:28px !important}.px-7{padding:0 28px 0 28px !important}.py-7{padding:28px 0 28px 0 !important}.h-7{height:28px !important}.pt-8{padding-top:32px !important}.pb-8{padding-bottom:32px !important}.pl-8{padding-left:32px !important}.pr-8{padding-right:32px !important}.mt-8{margin-top:32px !important}.mb-8{margin-bottom:32px !important}.ml-8{margin-left:32px !important}.mr-8{margin-right:32px !important}.m-8{margin:32px !important}.p-8{padding:32px !important}.px-8{padding:0 32px 0 32px !important}.py-8{padding:32px 0 32px 0 !important}.h-8{height:32px !important}.pt-9{padding-top:36px !important}.pb-9{padding-bottom:36px !important}.pl-9{padding-left:36px !important}.pr-9{padding-right:36px !important}.mt-9{margin-top:36px !important}.mb-9{margin-bottom:36px !important}.ml-9{margin-left:36px !important}.mr-9{margin-right:36px !important}.m-9{margin:36px !important}.p-9{padding:36px !important}.px-9{padding:0 36px 0 36px !important}.py-9{padding:36px 0 36px 0 !important}.h-9{height:36px !important}.pt-10{padding-top:40px !important}.pb-10{padding-bottom:40px !important}.pl-10{padding-left:40px !important}.pr-10{padding-right:40px !important}.mt-10{margin-top:40px !important}.mb-10{margin-bottom:40px !important}.ml-10{margin-left:40px !important}.mr-10{margin-right:40px !important}.m-10{margin:40px !important}.p-10{padding:40px !important}.px-10{padding:0 40px 0 40px !important}.py-10{padding:40px 0 40px 0 !important}.h-10{height:40px !important}.pt-11{padding-top:44px !important}.pb-11{padding-bottom:44px !important}.pl-11{padding-left:44px !important}.pr-11{padding-right:44px !important}.mt-11{margin-top:44px !important}.mb-11{margin-bottom:44px !important}.ml-11{margin-left:44px !important}.mr-11{margin-right:44px !important}.m-11{margin:44px !important}.p-11{padding:44px !important}.px-11{padding:0 44px 0 44px !important}.py-11{padding:44px 0 44px 0 !important}.h-11{height:44px !important}.pt-12{padding-top:48px !important}.pb-12{padding-bottom:48px !important}.pl-12{padding-left:48px !important}.pr-12{padding-right:48px !important}.mt-12{margin-top:48px !important}.mb-12{margin-bottom:48px !important}.ml-12{margin-left:48px !important}.mr-12{margin-right:48px !important}.m-12{margin:48px !important}.p-12{padding:48px !important}.px-12{padding:0 48px 0 48px !important}.py-12{padding:48px 0 48px 0 !important}.h-12{height:48px !important}.pt-13{padding-top:52px !important}.pb-13{padding-bottom:52px !important}.pl-13{padding-left:52px !important}.pr-13{padding-right:52px !important}.mt-13{margin-top:52px !important}.mb-13{margin-bottom:52px !important}.ml-13{margin-left:52px !important}.mr-13{margin-right:52px !important}.m-13{margin:52px !important}.p-13{padding:52px !important}.px-13{padding:0 52px 0 52px !important}.py-13{padding:52px 0 52px 0 !important}.h-13{height:52px !important}.pt-14{padding-top:56px !important}.pb-14{padding-bottom:56px !important}.pl-14{padding-left:56px !important}.pr-14{padding-right:56px !important}.mt-14{margin-top:56px !important}.mb-14{margin-bottom:56px !important}.ml-14{margin-left:56px !important}.mr-14{margin-right:56px !important}.m-14{margin:56px !important}.p-14{padding:56px !important}.px-14{padding:0 56px 0 56px !important}.py-14{padding:56px 0 56px 0 !important}.h-14{height:56px !important}.pt-15{padding-top:60px !important}.pb-15{padding-bottom:60px !important}.pl-15{padding-left:60px !important}.pr-15{padding-right:60px !important}.mt-15{margin-top:60px !important}.mb-15{margin-bottom:60px !important}.ml-15{margin-left:60px !important}.mr-15{margin-right:60px !important}.m-15{margin:60px !important}.p-15{padding:60px !important}.px-15{padding:0 60px 0 60px !important}.py-15{padding:60px 0 60px 0 !important}.h-15{height:60px !important}.pt-16{padding-top:64px !important}.pb-16{padding-bottom:64px !important}.pl-16{padding-left:64px !important}.pr-16{padding-right:64px !important}.mt-16{margin-top:64px !important}.mb-16{margin-bottom:64px !important}.ml-16{margin-left:64px !important}.mr-16{margin-right:64px !important}.m-16{margin:64px !important}.p-16{padding:64px !important}.px-16{padding:0 64px 0 64px !important}.py-16{padding:64px 0 64px 0 !important}.h-16{height:64px !important}.pt-17{padding-top:68px !important}.pb-17{padding-bottom:68px !important}.pl-17{padding-left:68px !important}.pr-17{padding-right:68px !important}.mt-17{margin-top:68px !important}.mb-17{margin-bottom:68px !important}.ml-17{margin-left:68px !important}.mr-17{margin-right:68px !important}.m-17{margin:68px !important}.p-17{padding:68px !important}.px-17{padding:0 68px 0 68px !important}.py-17{padding:68px 0 68px 0 !important}.h-17{height:68px !important}.pt-18{padding-top:72px !important}.pb-18{padding-bottom:72px !important}.pl-18{padding-left:72px !important}.pr-18{padding-right:72px !important}.mt-18{margin-top:72px !important}.mb-18{margin-bottom:72px !important}.ml-18{margin-left:72px !important}.mr-18{margin-right:72px !important}.m-18{margin:72px !important}.p-18{padding:72px !important}.px-18{padding:0 72px 0 72px !important}.py-18{padding:72px 0 72px 0 !important}.h-18{height:72px !important}.pt-19{padding-top:76px !important}.pb-19{padding-bottom:76px !important}.pl-19{padding-left:76px !important}.pr-19{padding-right:76px !important}.mt-19{margin-top:76px !important}.mb-19{margin-bottom:76px !important}.ml-19{margin-left:76px !important}.mr-19{margin-right:76px !important}.m-19{margin:76px !important}.p-19{padding:76px !important}.px-19{padding:0 76px 0 76px !important}.py-19{padding:76px 0 76px 0 !important}.h-19{height:76px !important}.pt-20{padding-top:80px !important}.pb-20{padding-bottom:80px !important}.pl-20{padding-left:80px !important}.pr-20{padding-right:80px !important}.mt-20{margin-top:80px !important}.mb-20{margin-bottom:80px !important}.ml-20{margin-left:80px !important}.mr-20{margin-right:80px !important}.m-20{margin:80px !important}.p-20{padding:80px !important}.px-20{padding:0 80px 0 80px !important}.py-20{padding:80px 0 80px 0 !important}.h-20{height:80px !important}.d-block{display:block}.w-full{width:100%}.a11y--focused{border-radius:4px;box-shadow:0 0 1px 3px rgba(var(--link-color-rgb), 0.5),0 0 0 1px var(--link-color)}.pos-relative{position:relative}.hidden-label{position:absolute;overflow:hidden;width:1px;height:1px;padding:0;border:0;margin:-1px}.overflow--visible{overflow:visible}.bg--white{background:var(--center-channel-bg)}.AdminPanel{padding:0;border:solid 1px rgba(0,0,0,.1);margin:2em 0 1em;border-radius:2px;box-shadow:0 1px 2px 0 rgba(0,0,0,.5);font-size:.95em}.AdminPanel .AdminPanel__content{padding:10px 20px 20px}.AdminPanel .AdminPanel__table{width:100%}.AdminPanel .AdminPanel__table th{border-bottom:solid 1px rgba(0,0,0,.1)}.AdminPanel .AdminPanel__table td,.AdminPanel .AdminPanel__table th{padding:6px 20px}.AdminPanel .AdminPanel__table td:first-child,.AdminPanel .AdminPanel__table th:first-child{padding-left:20px}.AdminPanel .header{display:flex;flex-direction:row;align-items:center;justify-content:space-between;padding:20px;background:#fff}.AdminPanel .header h3{padding:0;margin:0;font-size:18px;font-weight:normal}.AdminPanel .header .button{align-self:flex-end;margin-left:10px}.AdminPanel .header .button svg{transform:rotate(0deg);transition:transform 300ms}.AdminPanel.closed .header .button svg{transform:rotate(90deg);transition:transform 300ms}
.IPFilteringAddOrEditModal .modal-dialog{position:absolute;top:50%;left:50%;width:600px;border:1 px solid rgba(var(--center-channel-color-rgb), 0.08);margin:auto;border-radius:12px;transform:translate(-50%, -50%) !important}.IPFilteringAddOrEditModal .modal-content{border-radius:12px}.IPFilteringAddOrEditModal .modal-header{display:block;min-height:48px;padding-top:26px;padding-right:32px;padding-bottom:0;padding-left:32px;border:0;background:var(--center-channel-bg) !important;border-radius:12px;color:var(--center-channel-color)}.IPFilteringAddOrEditModal .modal-header .close{top:26px;right:26px;width:24px;height:24px;border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.56) !important;font-family:"Open Sans",sans-serif;font-size:32px;font-weight:400}.IPFilteringAddOrEditModal .modal-header .close:hover{background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72)}.IPFilteringAddOrEditModal .modal-header .close:active{background-color:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg)}.IPFilteringAddOrEditModal .modal-header .title{font-family:Metropolis,sans-serif;font-size:22px;font-style:normal;font-weight:600;line-height:28px;text-align:left}.IPFilteringAddOrEditModal .modal-body{display:flex;overflow:hidden;width:100%;flex-direction:column;padding-top:24px;padding-right:32px;padding-bottom:26px;padding-left:32px}.IPFilteringAddOrEditModal .modal-body .current_ip_notice{display:flex;max-width:536px;height:52px;border:1px rgba(87,158,255,.16) solid;background:rgba(87,158,255,.08);border-radius:4px}.IPFilteringAddOrEditModal .modal-body .current_ip_notice .Content{display:flex;width:536px;height:52px;padding:16px;color:var(--center-channel-color, #3f4350);font-family:Open Sans;font-size:14px;font-style:normal;font-weight:600;gap:12px;line-height:20px}.IPFilteringAddOrEditModal .modal-body .current_ip_notice .Content span{display:flex;height:20px;align-items:center;line-height:20px}.IPFilteringAddOrEditModal .modal-body .current_ip_notice .Content span svg{width:20px;height:20px;margin-right:12px;fill:#5d89ea}.IPFilteringAddOrEditModal .modal-body .inputs{color:var(--center-channel-color, #3f4350);font-family:Open Sans;font-size:14px;font-style:normal;font-weight:600;line-height:20px}.IPFilteringAddOrEditModal .modal-body .inputs>div{margin-top:24px}.IPFilteringAddOrEditModal .modal-body .inputs>div .Input_container{margin-top:8px}.IPFilteringAddOrEditModal .modal-body .inputs>div input{font-weight:normal}.IPFilteringAddOrEditModal .modal-body .inputs>p{margin-top:8px;font-weight:400}.IPFilteringAddOrEditModal .modal-body .buttons{margin-top:32px;text-align:right}.IPFilteringAddOrEditModal .modal-body .buttons .confirm-btn{height:40px;flex:none;padding:12px 20px;border:none;margin-left:8px;background:var(--button-bg);border-radius:4px;color:var(--sys-button-color);font-size:14px;font-weight:600;line-height:14px}.IPFilteringAddOrEditModal .modal-body .buttons .confirm-btn:hover,.IPFilteringAddOrEditModal .modal-body .buttons .confirm-btn:active,.IPFilteringAddOrEditModal .modal-body .buttons .confirm-btn:focus,.IPFilteringAddOrEditModal .modal-body .buttons .confirm-btn:active:focus{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}.IPFilteringAddOrEditModal .modal-footer{padding:24px 32px;border-top:none;border-radius:12px;font-family:Open Sans;font-size:14px;font-style:normal;font-weight:600;line-height:20px}.IPFilteringAddOrEditModal .modal-footer .btn-cancel{padding:10px 20px;border:none;background:var(--button-bg-8, rgba(28, 88, 217, 0.08));border-radius:4px;color:var(--button-bg, #1c58d9)}.IPFilteringAddOrEditModal .modal-footer .btn-save{padding:10px 20px;border:none;margin-left:8px;background:var(--button-bg, #1c58d9);border-radius:4px;color:var(--button-color, #fff)}.IPFilteringAddOrEditModal .modal-footer .btn-save:disabled{background:rgba(63,67,80,.08);color:rgba(63,67,80,.32);cursor:not-allowed}
.DeleteConfirmationModal .modal-dialog{position:absolute;top:50%;left:50%;width:600px;border:1 px solid rgba(var(--center-channel-color-rgb), 0.08);margin:auto;border-radius:12px;transform:translate(-50%, -50%) !important}.DeleteConfirmationModal .modal-content{border-radius:12px}.DeleteConfirmationModal .modal-header{display:block;min-height:48px;padding-top:26px;padding-bottom:0;padding-left:32px;border:0;background:var(--center-channel-bg) !important;border-radius:12px;color:var(--center-channel-color)}.DeleteConfirmationModal .modal-header .close{top:26px;right:26px;width:24px;height:24px;border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.56) !important;font-family:"Open Sans",sans-serif;font-size:32px;font-weight:400}.DeleteConfirmationModal .modal-header .close:hover{background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72)}.DeleteConfirmationModal .modal-header .close:active{background-color:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg)}.DeleteConfirmationModal .modal-header .title{font-family:Metropolis,sans-serif;font-size:22px;font-style:normal;font-weight:600;line-height:28px;text-align:left}.DeleteConfirmationModal .modal-body{overflow:hidden;width:100%;flex-direction:column;padding-top:24px;padding-right:32px;padding-bottom:26px;padding-left:32px;color:var(--center-channel-color, #3f4350);font-family:Open Sans;font-size:14px;font-style:normal;font-weight:400;line-height:20px}.DeleteConfirmationModal .modal-footer{padding:24px 32px;border-top:none;border-radius:12px;font-family:Open Sans;font-size:14px;font-style:normal;font-weight:600;line-height:20px}.DeleteConfirmationModal .modal-footer .btn-cancel{padding:10px 20px;border:none;background:var(--button-bg-8, rgba(28, 88, 217, 0.08));border-radius:4px;color:var(--button-bg, #1c58d9)}.DeleteConfirmationModal .modal-footer .btn-delete{padding:10px 20px;border:none;margin-left:8px;background:var(--denim-status-do-not-disturb, #d24b4e);border-radius:4px;color:var(--button-color, #fff)}
.EditSection{width:920px;height:auto;max-height:100%;border:1px solid rgba(var(--center-channel-color-rgb), 0.08);background:var(--center-channel-bg);border-radius:4px;box-shadow:0 2px 3px 0 rgba(0,0,0,.08)}.EditSection .TableSectionContent{display:inline-flex;width:100%;flex-direction:column;padding:20px}.EditSection .TableSectionContent .Table{display:flex;flex-direction:column;align-items:flex-start;align-self:stretch;justify-content:flex-start}.EditSection .TableSectionContent .Table .HeaderRow{display:flex;align-items:center;align-self:stretch;padding:10px 12px;border-bottom:1px solid var(--center-channel-color-16, rgba(63, 67, 80, 0.16));background-color:#f5f5f5;font-family:"Open Sans";font-size:14px;font-weight:600;gap:10px;line-height:20px}.EditSection .TableSectionContent .Table .HeaderRow .FilterName,.EditSection .TableSectionContent .Table .HeaderRow .IpAddressRange{color:#3f4350;font-family:"Open Sans";font-size:14px;line-height:20px;word-wrap:break-word}.EditSection .TableSectionContent .Table .HeaderRow .FilterName{width:291px;font-weight:600}.EditSection .TableSectionContent .Table .HeaderRow .IpAddressRange{flex:1 1 0}.EditSection .TableSectionContent .Table .Row{display:inline-flex;height:40px;align-items:center;align-self:stretch;justify-content:flex-start;padding:10px 12px;border-bottom:1px solid var(--center-channel-color-8, rgba(63, 67, 80, 0.08));background:#fff;gap:10px}.EditSection .TableSectionContent .Table .Row .FilterName,.EditSection .TableSectionContent .Table .Row .IpAddressRange{color:#3f4350;font-family:"Open Sans";font-size:14px;line-height:20px;word-wrap:break-word}.EditSection .TableSectionContent .Table .Row .FilterName{width:291px}.EditSection .TableSectionContent .Table .Row .IpAddressRange{flex:1 1 0}.EditSection .TableSectionContent .Table .Row .Actions{display:flex;align-items:center;justify-content:center}.EditSection .TableSectionContent .Table .Row .Actions>div{display:flex;align-items:center;justify-content:center;padding:6px;border-radius:4px}.EditSection .TableSectionContent .Table .Row .Actions>div:hover{background:var(--center-channel-color-8, rgba(63, 67, 80, 0.08))}.EditSection .TableSectionContent .Table .Row .Actions>div.edit{color:var(--center-channel-color-72, rgba(63, 67, 80, 0.72))}.EditSection .TableSectionContent .Table .Row .Actions>div.delete{color:var(--error-text, rgb(210, 75, 78))}.EditSection .NoFilters{display:flex;flex-direction:column;align-items:center;justify-content:center;padding:32px 20px}.EditSection .NoFilters .Title{color:var(--center-channel-color, #3f4350);font-family:Metropolis;font-size:20px;font-style:normal;font-weight:600;line-height:28px;text-align:center}.EditSection .NoFilters .Subtitle{max-width:320px;margin-top:8px;color:var(--center-channel-color-72, rgba(63, 67, 80, 0.72));font-family:Open Sans;font-size:14px;font-style:normal;font-weight:400;line-height:20px;text-align:center}.EditSection .NoFilters .Subtitle .Button{display:inline;height:20px;padding:0;background:none;color:var(--link-color, #1c58d9);font-family:Open Sans;font-size:14px;font-style:normal;font-weight:400;line-height:20px;text-align:center}.EditSection .NoFilters .Subtitle .Button:hover{cursor:pointer}.EditSection .AllowedIPAddressesSection{display:inline-flex;width:100%;flex-direction:column;align-items:flex-start;justify-content:flex-start}.EditSection .AllowedIPAddressesSection .SectionHeaderContent{display:flex;flex-direction:column;align-items:flex-start;align-self:stretch;justify-content:flex-start;padding:24px 32px;border-bottom:1px solid rgba(63,67,80,.12);gap:24px}.EditSection .AllowedIPAddressesSection .SectionHeaderContent .HeaderContent{display:inline-flex;align-items:flex-start;align-self:stretch;justify-content:flex-start;gap:32px}.EditSection .AllowedIPAddressesSection .SectionHeaderContent .HeaderContent .TitleSubtitle{display:inline-flex;flex:1 1 0;flex-direction:column;align-items:flex-start;justify-content:center}.EditSection .AllowedIPAddressesSection .SectionHeaderContent .HeaderContent .TitleSubtitle .Title{color:#3f4350;font-family:Metropolis;font-size:16px;font-weight:600;line-height:24px;word-wrap:break-word}.EditSection .AllowedIPAddressesSection .SectionHeaderContent .HeaderContent .TitleSubtitle .Subtitle{align-self:stretch;color:#3f4350;font-family:"Open Sans";font-size:14px;font-weight:400;line-height:20px;word-wrap:break-word}.EditSection .AllowedIPAddressesSection .SectionHeaderContent .HeaderContent .AddIPFilterButton{display:inline-flex;flex-direction:column;align-items:flex-end;justify-content:flex-start;border:none;background:none;gap:16px}.EditSection .AllowedIPAddressesSection .SectionHeaderContent .HeaderContent .AddIPFilterButton .Button{display:flex;flex-direction:column;align-items:center;justify-content:flex-start;padding:10px 16px;border:none;background:#1c58d9;border-radius:4px;color:#fff;gap:10px}.EditSection .AllowedIPAddressesSection .SectionHeaderContent .NotInRangeErrorPanel{display:inline-flex;width:856px;justify-content:flex-start;padding:16px;border:1px solid var(--error-text-16, rgba(210, 75, 78, 0.16));background:var(--error-text-8, rgba(210, 75, 78, 0.08));border-radius:4px;gap:12px}.EditSection .AllowedIPAddressesSection .SectionHeaderContent .NotInRangeErrorPanel .Icon{color:var(--error-text, #d24b4e)}.EditSection .AllowedIPAddressesSection .SectionHeaderContent .NotInRangeErrorPanel .Content{display:inline-flex;flex:1 1 0;flex-direction:column;align-items:flex-start;justify-content:flex-start;padding-right:24px;gap:8px}.EditSection .AllowedIPAddressesSection .SectionHeaderContent .NotInRangeErrorPanel .Content .Title{align-self:stretch;color:#3f4350;font-family:"Open Sans";font-size:14px;font-weight:600;line-height:20px;word-wrap:break-word}.EditSection .AllowedIPAddressesSection .SectionHeaderContent .NotInRangeErrorPanel .Content .Body{align-self:stretch;color:#3f4350;font-family:"Open Sans";font-size:14px;font-weight:400;line-height:20px;word-wrap:break-word}.EditSection .AllowedIPAddressesSection .SectionHeaderContent .NotInRangeErrorPanel .Content .Button{display:inline;height:16px;padding:0;padding-left:2px;background:none;color:var(--button-bg, rgb(28, 88, 217));font-size:14px;font-weight:600;line-height:20px}.EditSection .AllowedIPAddressesSection .SectionHeaderContent .NotInRangeErrorPanel .Content .Button:hover{cursor:pointer}
.SaveConfirmationModal .modal-dialog{position:absolute;top:50%;left:50%;width:600px;border:1 px solid rgba(var(--center-channel-color-rgb), 0.08);margin:auto;border-radius:12px;transform:translate(-50%, -50%) !important}.SaveConfirmationModal .modal-content{border-radius:12px}.SaveConfirmationModal .modal-header{display:block;min-height:48px;padding-top:26px;padding-bottom:0;padding-left:32px;border:0;background:var(--center-channel-bg) !important;border-radius:12px;color:var(--center-channel-color)}.SaveConfirmationModal .modal-header .close{top:26px;right:26px;width:24px;height:24px;border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.56) !important;font-family:"Open Sans",sans-serif;font-size:32px;font-weight:400}.SaveConfirmationModal .modal-header .close:hover{background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72)}.SaveConfirmationModal .modal-header .close:active{background-color:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg)}.SaveConfirmationModal .modal-header .title{font-family:Metropolis,sans-serif;font-size:22px;font-style:normal;font-weight:600;line-height:28px;text-align:left}.SaveConfirmationModal .modal-body{overflow:hidden;width:100%;flex-direction:column;padding-top:24px;padding-right:32px;padding-bottom:26px;padding-left:32px;color:var(--center-channel-color, #3f4350);font-family:Open Sans;font-size:14px;font-style:normal;font-weight:400;line-height:20px}.SaveConfirmationModal .modal-body .disclaimer{display:inline-flex;width:536px;height:120px;align-items:flex-start;justify-content:flex-start;padding:16px;border:1px solid rgba(87,158,255,.16);margin-top:32px;background:rgba(87,158,255,.08);border-radius:4px;gap:12px}.SaveConfirmationModal .modal-body .disclaimer .Icon{display:flex;align-items:center;justify-content:flex-start;gap:10px}.SaveConfirmationModal .modal-body .disclaimer .Icon svg{width:20px;height:20px;fill:var(--sidebar-text-active-border, rgb(93, 137, 234))}.SaveConfirmationModal .modal-body .disclaimer .Body{display:inline-flex;flex:1 1 0;flex-direction:column;align-items:flex-start;justify-content:flex-start;padding-right:24px;gap:8px}.SaveConfirmationModal .modal-body .disclaimer .Body .Title{align-self:stretch;color:#3f4350;font-family:"Open Sans";font-size:14px;font-weight:600;line-height:20px;word-wrap:break-word}.SaveConfirmationModal .modal-body .disclaimer .Body .Subtitle{color:#3f4350;font-family:"Open Sans";font-size:14px;font-weight:400;line-height:20px;word-wrap:break-word}.SaveConfirmationModal .modal-footer{padding:24px 32px;border-top:none;border-radius:12px;font-family:Open Sans;font-size:14px;font-style:normal;font-weight:600;line-height:20px}.SaveConfirmationModal .modal-footer .btn-cancel{padding:10px 20px;border:none;background:var(--button-bg-8, rgba(28, 88, 217, 0.08));border-radius:4px;color:var(--button-bg, #1c58d9)}.SaveConfirmationModal .modal-footer .btn-delete{padding:10px 20px;border:none;margin-left:8px;background:var(--denim-status-do-not-disturb, #d24b4e);border-radius:4px;color:var(--button-color, #fff)}
.IPFiltering{height:100%}.IPFiltering .admin-console-save .btn.btn-primary:disabled{color:rgba(var(--center-channel-color-rgb), 0.32) !important}.IPFiltering .MainPanel{display:flex;height:100%;flex-direction:column;align-items:flex-start;padding:20px;gap:20px}.IPFiltering .MainPanel .EnableSectionContent{display:inline-flex;width:920px;height:92px;flex-direction:column;align-items:flex-start;justify-content:flex-start;padding:24px 32px;border:1px solid rgba(var(--center-channel-color-rgb), 0.08);background-color:var(--center-channel-bg);border-radius:4px;box-shadow:0 2px 3px 0 rgba(0,0,0,.08);gap:24px}.IPFiltering .MainPanel .EnableSectionContent .TitleSubtitleContent{display:inline-flex;align-items:flex-start;align-self:stretch;justify-content:flex-start;gap:32px}.IPFiltering .MainPanel .EnableSectionContent .TitleSubtitleContent .TitleSubtitle{flex:1 1 0;flex-direction:column;align-items:flex-start;justify-content:center;gap:24px}.IPFiltering .MainPanel .EnableSectionContent .TitleSubtitleContent .TitleSubtitle .Title{color:#3f4350;font-family:Metropolis;font-size:16px;font-weight:600;line-height:24px;word-wrap:break-word}.IPFiltering .MainPanel .EnableSectionContent .TitleSubtitleContent .TitleSubtitle .Subtitle{align-self:stretch;color:#3f4350;font-family:"Open Sans";font-size:14px;font-weight:400;line-height:20px;word-wrap:break-word}.IPFiltering .MainPanel .EnableSectionContent .TitleSubtitleContent .SwitchSelector{width:32px;height:20px;flex-shrink:0}.IPFiltering .error-message{display:flex;align-items:center;justify-content:center;color:var(--error-text, #d24b4e);font-size:14px;line-height:20px}.IPFiltering .error-message>svg{margin-right:7px;margin-left:7px}.IPFiltering .error-message .saving-message-description{margin-left:16px;color:rgba(var(--center-channel-color-rgb), 0.72) !important}
.self_hosted_expansion_failed{margin-top:163px}
.SelfHostedPurchaseModal__success{display:flex;overflow:hidden;width:100%;height:100%;flex-direction:row;flex-grow:1;flex-wrap:wrap;align-content:center;justify-content:center;padding:77px 107px;color:var(--center-channel-color);font-size:16px;font-weight:600}.self_hosted_expansion_success{overflow:hidden}.self_hosted_expansion_success .selfHostedExpansionModal__success{margin-top:163px}
.SelfHostedExpansionRHSCard{display:flex;width:280px;flex-direction:column}.SelfHostedExpansionRHSCard__Content{padding:24px;border:1px solid;border-color:rgba(var(--sys-denim-center-channel-text-rgb), 0.16);border-radius:4px}.SelfHostedExpansionRHSCard__RHSCardTitle{display:block;margin-bottom:12px;color:rgba(var(--sys-denim-center-channel-text-rgb), 0.72);font-size:14px;font-weight:600;text-align:center;text-transform:capitalize}.SelfHostedExpansionRHSCard .seatsInput{width:73px;margin-left:auto;font-size:14px;font-weight:400}.SelfHostedExpansionRHSCard .seatsInput input[type=number]{text-align:right}.SelfHostedExpansionRHSCard .seatsInput input[type=number]::-webkit-inner-spin-button,.SelfHostedExpansionRHSCard .seatsInput input[type=number]::-webkit-outer-spin-button{margin:0;-webkit-appearance:none}.SelfHostedExpansionRHSCard__PlanDetails{display:flex;flex-direction:column;text-align:center}.SelfHostedExpansionRHSCard__PlanDetails .planName{color:rgba(var(--sys-denim-center-channel-text-rgb), 0.72);font-size:20px;font-weight:400;text-transform:capitalize}.SelfHostedExpansionRHSCard__PlanDetails .usage{color:rgba(var(--sys-denim-center-channel-text-rgb), 0.56);font-size:12px;font-weight:600}.SelfHostedExpansionRHSCard__PlanDetails .usage :first-child{text-transform:uppercase}.SelfHostedExpansionRHSCard hr{width:90%;height:2px;background-color:rgba(var(--sys-denim-center-channel-text-rgb), 0.16)}.SelfHostedExpansionRHSCard__seatInput,.SelfHostedExpansionRHSCard__cost_breakdown{display:grid;font-weight:400;gap:10px;grid-template-columns:repeat(2, 1fr)}.SelfHostedExpansionRHSCard__seatInput .costPerUser>span:first-child,.SelfHostedExpansionRHSCard__cost_breakdown .costPerUser>span:first-child{font-size:14px}.SelfHostedExpansionRHSCard__seatInput .costPerUser>span:last-child,.SelfHostedExpansionRHSCard__cost_breakdown .costPerUser>span:last-child{color:rgba(var(--sys-denim-center-channel-text-rgb), 0.72);font-size:12px}.SelfHostedExpansionRHSCard__seatInput .totalCostWarning,.SelfHostedExpansionRHSCard__cost_breakdown .totalCostWarning{width:141px}.SelfHostedExpansionRHSCard__seatInput .totalCostWarning>span:first-child,.SelfHostedExpansionRHSCard__cost_breakdown .totalCostWarning>span:first-child{color:var(--sys-denim-center-channel-text);font-size:14px;font-weight:700}.SelfHostedExpansionRHSCard__seatInput .totalCostWarning>span:last-child,.SelfHostedExpansionRHSCard__cost_breakdown .totalCostWarning>span:last-child{color:rgba(var(--sys-denim-center-channel-text-rgb), 0.72);font-size:12px}.SelfHostedExpansionRHSCard__seatInput .costAmount,.SelfHostedExpansionRHSCard__cost_breakdown .costAmount{width:100%;margin-right:0;margin-left:auto;font-weight:700}.SelfHostedExpansionRHSCard__AddSeatsWarning{display:block;width:100%;height:35px;margin-bottom:15px;color:var(--dnd-indicator);font-size:12px;font-weight:600;text-align:right}.SelfHostedExpansionRHSCard__CompletePurchaseButton{width:100%;margin-top:10px;margin-bottom:10px;border-radius:4px}.SelfHostedExpansionRHSCard__ChargedTodayDisclaimer{color:rgba(var(--sys-denim-center-channel-text-rgb), 0.72);font-size:12px;font-weight:400}
.submitting{overflow:hidden}.submitting .processing{margin-top:163px}
.SelfHostedExpansionModal{height:100%}.SelfHostedExpansionModal .form-view{display:flex;width:100%;height:100%;flex-direction:row;flex-grow:1;flex-wrap:wrap;align-content:top;justify-content:center;padding:77px 107px;color:var(--center-channel-color);font-family:"Open Sans";font-size:16px;font-weight:600;overflow-x:hidden}.SelfHostedExpansionModal .form-view .title{font-size:22px;font-weight:600}.SelfHostedExpansionModal .form-view .form{padding:0 96px;margin:0 auto}.SelfHostedExpansionModal .form-view .form .form-row{display:flex;width:100%;margin-bottom:24px}.SelfHostedExpansionModal .form-view .form .form-row-third-1{width:66%;max-width:288px;margin-right:16px}.SelfHostedExpansionModal .form-view .form .form-row-third-1 .DropdownInput{margin-top:0}.SelfHostedExpansionModal .form-view .form .DropdownInput{position:relative;height:36px;margin-bottom:24px}.SelfHostedExpansionModal .form-view .form .DropdownInput .Input_fieldset{height:43px}.SelfHostedExpansionModal .form-view .form .form-row-third-2{width:34%;max-width:144px}.SelfHostedExpansionModal .form-view .form .section-title{display:block;margin-bottom:10px;color:rgba(var(--center-channel-color-rgb), 0.72);font-size:16px;font-weight:600;text-align:left}.SelfHostedExpansionModal .form-view .form .Input_fieldset{height:40px;padding:2px 1px;background:var(--center-channel-bg)}.SelfHostedExpansionModal .form-view .form .Input_fieldset .Input{background:inherit}.SelfHostedExpansionModal .form-view .form .Input_fieldset .Input_wrapper{margin:0}.SelfHostedExpansionModal .form-view--hide{display:none}.SelfHostedExpansionModal .form-view>.lhs{width:25%}.SelfHostedExpansionModal .form-view>.center{width:50%}.SelfHostedExpansionModal .form-view>.rhs{position:sticky;display:flex;width:25%;flex-direction:column;align-items:center}.SelfHostedExpansionModal .form-view .submitting,.SelfHostedExpansionModal .form-view .success,.SelfHostedExpansionModal .form-view .failed{display:flex;overflow:hidden;width:100%;height:100%;flex-direction:row;flex-grow:1;flex-wrap:wrap;align-content:center;justify-content:center;padding:77px 107px;color:var(--center-channel-color);font-family:"Open Sans";font-size:16px;font-weight:600}.SelfHostedExpansionModal .form-view .submitting .IconMessage .content .IconMessage-link,.SelfHostedExpansionModal .form-view .success .IconMessage .content .IconMessage-link,.SelfHostedExpansionModal .form-view .failed .IconMessage .content .IconMessage-link{margin-left:0}.SelfHostedExpansionModal .form-view .background-svg{position:absolute;z-index:-1;top:0;width:100%;height:100%}.SelfHostedExpansionModal .form-view .background-svg>div{position:absolute;top:0;left:0}.SelfHostedExpansionModal .form-view .self-hosted-agreed-terms{font-size:16px}.SelfHostedExpansionModal .form-view .self-hosted-agreed-terms label{display:flex;align-items:flex-start;justify-content:flex-start}.SelfHostedExpansionModal .form-view .self-hosted-agreed-terms input[type=checkbox]{width:17px;height:17px;flex-shrink:0;margin-right:12px}@media(max-width: 1020px){.SelfHostedExpansionModal .SelfHostedExpansionModal .form-view>.lhs{display:none}.SelfHostedExpansionModal .SelfHostedExpansionModal .form-view>.center{width:66%}.SelfHostedExpansionModal .SelfHostedExpansionModal .form-view>.rhs{width:33%}}.SelfHostedExpansionModal .FullScreenModal .close-x{top:12px;right:12px}
.EnterpriseEditionRightPannel{font-family:Metropolis}.EnterpriseEditionRightPannel .svg-image{text-align:center}.EnterpriseEditionRightPannel .svg-image svg{margin:0 auto}.EnterpriseEditionRightPannel .upgrade-title{margin:10px 0;color:#3f4350;font-size:16px;font-weight:700;line-height:24px}.EnterpriseEditionRightPannel .advantages-list{margin:7px 0;font-size:12px;line-height:16px}.EnterpriseEditionRightPannel .advantages-list .item{margin:10px 0}.EnterpriseEditionRightPannel .advantages-list .item i{margin-right:5px}.EnterpriseEditionRightPannel .advantages-list :last-child{color:rgba(63,69,80,.72)}.EnterpriseEditionRightPannel button{width:100%;margin:5px auto;border-radius:4px}.EnterpriseEditionRightPannel .purchase_buttons{margin-top:20px}.EnterpriseEditionRightPannel .purchase_buttons button{height:48px !important;padding:7px 12px !important;margin:0 5px !important}.EnterpriseEditionRightPannel .upgrade-error{margin-top:10px}.EnterpriseEditionLeftPanel{font-family:Metropolis}.EnterpriseEditionLeftPanel__Grid{display:grid;grid-template-columns:repeat(2, 1fr);grid-template-rows:1fr}.EnterpriseEditionLeftPanel .PlanDetails__viewPlansButton{height:33px}.EnterpriseEditionLeftPanel .pre-title{margin-bottom:10px;color:rgba(63,67,80,.56) !important;font-size:12px;font-weight:600;line-height:16px}.EnterpriseEditionLeftPanel .title{display:flex;color:#3f4350;font-size:18px;font-weight:700;gap:4px;line-height:24px}.EnterpriseEditionLeftPanel .subtitle{margin-top:15px;font-size:12px}.EnterpriseEditionLeftPanel .license-notices{font-size:12px;text-align:justify}.EnterpriseEditionLeftPanel .licenseInformation{padding:24px;border:1px solid rgba(63,67,80,.16);margin:15px 0;border-radius:4px}.EnterpriseEditionLeftPanel .licenseInformation .license-details-top{display:flex;justify-content:space-between;font-size:14px;font-weight:700;line-height:24px}.EnterpriseEditionLeftPanel .licenseInformation .license-details-top span.title{display:inline-block;color:#3f4350}.EnterpriseEditionLeftPanel .licenseInformation .license-details-top .add-seats-button{border-radius:4px;font-family:"Open Sans",sans-serif;font-size:12px;font-weight:600}.EnterpriseEditionLeftPanel .licenseInformation .licenseElements .item-element{margin:15px 0;font-family:Open Sans;font-size:14px;line-height:20px}.EnterpriseEditionLeftPanel .licenseInformation .licenseElements .item-element span.legend{display:inline-block;min-width:150px;color:rgba(var(--secondary-blue-rgb), 0.4);font-weight:600}.EnterpriseEditionLeftPanel .licenseInformation .licenseElements .item-element span.legend--warning-over-seats-purchased{color:var(--warning-text)}.EnterpriseEditionLeftPanel .licenseInformation .licenseElements .item-element span.legend--over-seats-purchased{color:var(--error-text)}.EnterpriseEditionLeftPanel .licenseInformation .licenseElements .item-element span.value{margin-left:10px;color:var(--secondary-blue)}.EnterpriseEditionLeftPanel .licenseInformation .licenseElements .item-element span.value--warning-over-seats-purchased{color:var(--warning-text);font-weight:600}.EnterpriseEditionLeftPanel .licenseInformation .licenseElements .item-element span.value--over-seats-purchased{color:var(--error-text);font-weight:600}.EnterpriseEditionLeftPanel .licenseInformation .licenseElements .item-element span.expiration-days{margin-left:8px;font-size:14px;font-weight:600}.EnterpriseEditionLeftPanel .licenseInformation .licenseElements .item-element span.expiration-days-warning{color:var(--sys-away-indicator)}.EnterpriseEditionLeftPanel .licenseInformation .licenseElements .item-element span.expiration-days-danger{color:var(--dnd-indicator)}.EnterpriseEditionLeftPanel .licenseInformation .licenseElements .add-new-licence-btn{display:block;padding:12px 20px;border:1px solid var(--sys-button-bg);margin-top:15px;background-color:var(--sys-center-channel-bg);border-radius:4px;color:var(--sys-button-bg)}.EnterpriseEditionLeftPanel .licenseInformation .licenseElements .add-new-licence-btn span{font-size:14px;font-weight:600;line-height:14px}.EnterpriseEditionLeftPanel .licenseInformation #remove-button{padding:0;border:none !important;margin:10px 0;background:none !important;color:var(--error-text);font-weight:700}.EnterpriseEditionLeftPanel .licenseInformation #remove-button:hover{text-decoration:underline}.EnterpriseEditionLeftPanel .licenseInformation #remove-button:focus,.EnterpriseEditionLeftPanel .licenseInformation #remove-button:focus-visible{outline:none !important}
.ConfirmLicenseRemovalModal .modal-body{padding-top:0 !important;padding-bottom:40px !important}.ConfirmLicenseRemovalModal .content-body{display:flex;flex-direction:column;align-items:center;justify-content:center}.ConfirmLicenseRemovalModal .content-body .alert-svg{margin-top:-20px}.ConfirmLicenseRemovalModal .content-body .title{margin:10px 0;color:var(--sys-denim-center-channel-text);font-family:Metropolis;font-size:22px;font-weight:700;line-height:28px}.ConfirmLicenseRemovalModal .content-body .subtitle{width:90%;color:var(--sys-denim-center-channel-text);font-size:14px;font-style:normal;font-weight:normal;line-height:20px;text-align:center}.ConfirmLicenseRemovalModal .content-footer{display:flex;align-items:center;justify-content:center;margin-top:20px}.ConfirmLicenseRemovalModal .content-footer button{height:40px;margin-top:15px !important;margin-left:10px;border-radius:4px}.ConfirmLicenseRemovalModal .modal-footer{border-top:none !important;background:none !important}
.EELicenseModal .modal-header{background:none !important}.EELicenseModal .modal-header button.close span{color:rgba(63,67,80,.56) !important}.EELicenseModal .title{margin:10px 0;color:#3f4350;font-family:Metropolis;font-size:22px;font-weight:700;line-height:28px}.EELicenseModal .enterprise-license-text{max-height:200px;padding:10px;background:#fff;overflow-y:auto;text-align:justify}.EELicenseModal .content-footer{display:flex}.EELicenseModal .content-footer button{margin-top:15px !important;margin-left:auto;border-radius:4px}.EELicenseModal .modal-footer{border-top:none !important}
.UploadLicenseModal .modal-header{border-bottom:none !important;background:none !important}.UploadLicenseModal .modal-header button.close span{color:rgba(63,67,80,.56) !important}.UploadLicenseModal .modal-body{padding-top:0 !important;padding-bottom:24px !important}.UploadLicenseModal .content-body{display:flex;flex-direction:column;align-items:center;justify-content:center}.UploadLicenseModal .content-body .svg-image{margin-top:-20px}.UploadLicenseModal .content-body .hands-svg{margin-top:0;margin-bottom:15px}.UploadLicenseModal .content-body .title{margin:10px 0;color:#3f4350;font-family:Metropolis;font-size:22px;font-weight:700;line-height:28px}.UploadLicenseModal .content-body .subtitle{width:90%;color:#3f4350;font-size:14px;font-style:normal;font-weight:normal;line-height:20px;text-align:center}.UploadLicenseModal .content-body .file-upload{width:90%;padding:12px;border:1px solid rgba(63,67,80,.32);margin-top:15px;border-radius:4px}.UploadLicenseModal .content-body .file-upload__titleSection{color:rgba(63,67,80,.72);font-size:12px;font-weight:bold;line-height:16px}.UploadLicenseModal .content-body .file-upload__inputSection{display:flex;justify-content:space-between;margin-top:10px}.UploadLicenseModal .content-body .file-upload__inputSection .file-name-section{display:flex}.UploadLicenseModal .content-body .file-upload__inputSection .file-name-section svg{margin-right:5px}.UploadLicenseModal .content-body .file-upload__inputSection .file-name-section .file-size{margin-left:20px}.UploadLicenseModal .content-body .file-upload__inputSection .file__upload{position:relative;display:flex;align-self:flex-end;margin-left:auto}.UploadLicenseModal .content-body .file-upload__inputSection .file__upload a{color:#1c58d9;font-weight:600}.UploadLicenseModal .content-body .file-upload__inputSection .file__upload input{position:absolute;z-index:5;top:0;left:0;width:100%;height:100%;padding-left:100%;cursor:pointer}.UploadLicenseModal .content-body .file-upload__inputSection .file__upload input[disabled]{cursor:not-allowed}.UploadLicenseModal .content-body .serverError{display:flex;width:90%;margin-top:5px;color:var(--error-text);float:left}.UploadLicenseModal .content-body .serverError i{display:inline;margin-right:5px}.UploadLicenseModal .content-body .serverError span.server-error-text{display:inline-flex}.UploadLicenseModal .content-footer{display:flex;flex-direction:column;align-items:center;justify-content:center;margin-top:20px}.UploadLicenseModal .content-footer button{height:48px;padding:5px 24px;border:0 !important;margin-top:15px !important;border-radius:4px;font-size:16px;font-weight:600;line-height:18px}.UploadLicenseModal .modal-footer{border-top:none !important;background:none !important}
.RenewLicenseCard .annnouncementBar__purchaseNow{display:block;padding:12px 20px;border:none;margin-top:15px;background:var(--sys-button-bg);border-radius:4px;color:var(--sys-button-color)}.RenewLicenseCard .annnouncementBar__purchaseNow span{font-size:14px;font-weight:600;line-height:14px}.RenewLicenseCard__buttons{display:flex}.RenewLicenseCard__text-title{margin-bottom:5px;color:var(--sys-sidebar-text-active-border);font-family:Open Sans;font-size:18px;font-style:normal;font-weight:600;line-height:24px}.RenewLicenseCard__text-title.critical{color:var(--sys-error-text)}.RenewLicenseCard__text-description{margin-bottom:5px;color:var(--sys-center-channel-color);font-family:Open Sans;font-size:14px;font-style:normal;line-height:30px}.RenewLicenseCard__text-description.bolder{font-weight:600}.RenewLicenseCard__licensedUsersNum{display:inline-block}.RenewLicenseCard__activeUsersNum{display:inline-block;margin-left:25px}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.StarterEditionRightPannel .svg-image{text-align:center}.StarterEditionRightPannel .svg-image svg{margin:0 auto}.StarterEditionRightPannel .upgrade-title{margin:10px 0;color:#3f4350;font-family:Metropolis;font-size:16px;font-weight:700;line-height:24px}.StarterEditionRightPannel .advantages-list{margin:7px 0;font-size:12px;line-height:16px}.StarterEditionRightPannel .advantages-list .item{margin:10px 0}.StarterEditionRightPannel .advantages-list .item i{margin-right:5px}.StarterEditionRightPannel .advantages-list :last-child{color:rgba(63,69,80,.72)}.StarterEditionRightPannel .purchase_buttons{display:flex;flex-direction:row;justify-content:space-between;margin-top:20px}.StarterEditionRightPannel .purchase_buttons button{width:120px;padding:14px 12px !important;border-radius:4px}.StarterEditionRightPannel .purchase_buttons button span{font-size:16px !important}.StarterEditionRightPannel .purchase_buttons button.contact-us{width:130px;margin-left:15px}@media screen and (max-width: 1130px){.StarterEditionRightPannel .purchase_buttons{flex-direction:column}.StarterEditionRightPannel .purchase_buttons button{width:100% !important}.StarterEditionRightPannel .purchase_buttons button.contact-us{margin-top:10px;margin-left:0 !important}}.StarterEditionRightPannel .upgrade-error{margin-top:10px}.StarterLeftPanel{position:relative}.StarterLeftPanel .PlanDetails__viewPlansButton{position:absolute;right:10px;display:block;margin-left:auto}.StarterLeftPanel .PlanDetails__viewPlansButton.btn{display:inline-flex;align-items:center;border:0;background:rgba(var(--button-bg-rgb), 0.08);border-radius:4px;color:var(--button-bg);font-weight:600;transition:all .15s ease-out}.StarterLeftPanel .PlanDetails__viewPlansButton.btn:disabled{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32)}.StarterLeftPanel .PlanDetails__viewPlansButton.btn:hover:enabled{background:rgba(var(--button-bg-rgb), 0.12)}.StarterLeftPanel .PlanDetails__viewPlansButton.btn:active:enabled{background:rgba(var(--button-bg-rgb), 0.16)}.StarterLeftPanel .PlanDetails__viewPlansButton.btn i{display:flex;font-size:18px}.StarterLeftPanel .PlanDetails__viewPlansButton.btn i:first-child::before{margin:0 7px 0 0}.StarterLeftPanel .PlanDetails__viewPlansButton.btn i:last-child::before{margin:0 0 0 7px}.StarterLeftPanel .pre-title{margin-bottom:10px;color:rgba(63,67,80,.56) !important;font-size:12px;font-weight:600;line-height:16px}.StarterLeftPanel .title{color:#3f4350;font-family:Metropolis;font-size:18px;font-weight:700;line-height:24px}.StarterLeftPanel .subtitle{color:#3d3c40;font-size:12px;font-style:normal;font-weight:normal;line-height:16px}.StarterLeftPanel .content{margin:25px 0;font-size:12px}.StarterLeftPanel .licenseInformation{border-radius:4px}.StarterLeftPanel .licenseInformation .licenseKeyTitle{font-family:Metropolis;font-size:16px;font-weight:700;line-height:24px}.StarterLeftPanel .licenseInformation .uploadButtons{margin-top:10px}.StarterLeftPanel .licenseInformation .uploadButtons input{display:hidden}.StarterLeftPanel .licenseInformation .uploadButtons button{height:48px;border-radius:4px}.StarterLeftPanel .licenseInformation .uploadButtons .help-text{font-size:12px}
.TeamEditionRightPanel .svg-image{text-align:center}.TeamEditionRightPanel .svg-image svg{margin:0 auto}.TeamEditionRightPanel .upgrade-title{margin:10px 0;color:#3f4350;font-family:Metropolis;font-size:16px;font-weight:700;line-height:24px}.TeamEditionRightPanel .advantages-list{margin:7px 0;font-size:12px;line-height:16px}.TeamEditionRightPanel .advantages-list .item{margin:10px 0}.TeamEditionRightPanel .advantages-list .item i{margin-right:5px}.TeamEditionRightPanel .advantages-list :last-child{color:rgba(63,69,80,.72)}.TeamEditionRightPanel button{width:100%;margin:5px auto;border-radius:4px}.TeamEditionRightPanel .upgrade-error{margin-top:10px}.TeamEditionLeftPanel .title{color:#3f4350;font-family:Metropolis;font-size:18px;font-weight:700;line-height:24px}
.RenewLicenseCard.TrialLicense .TrialLicenseCard__text-title{margin-bottom:22px;color:var(--sys-button-bg);font-size:18px;font-style:normal;font-weight:600;line-height:18px}.RenewLicenseCard.TrialLicense .RenewLicenseCard__buttons button{padding:6px 12px !important}.RenewLicenseCard.TrialLicense .RenewLicenseCard__text-description{margin-bottom:16px;line-height:20px}.RenewLicenseCard.TrialLicense button{display:inline-block;margin-top:0}.RenewLicenseCard.TrialLicense button.contact-us{padding:11px 19px;margin-left:10px}
.purchase-card{display:flex}.top-wrapper{display:flex}.top-wrapper .left-panel{width:568px}.top-wrapper .left-panel .panel-card{padding:28px 32px;border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08);background:var(--sys-center-channel-bg);border-radius:4px;box-shadow:0 2px 3px rgba(0,0,0,.08)}.top-wrapper .right-panel{width:332px;margin-left:20px}.top-wrapper .right-panel .panel-card{padding:28px 32px;border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08);background:var(--sys-center-channel-bg);border-radius:4px;box-shadow:0 2px 3px rgba(0,0,0,.08)}.top-wrapper .terms-and-policy{margin-top:15px}.top-wrapper .compare-plans-text{margin-top:15px}.banner-start-trial .license-trial-legal-terms{color:#3f4350}.light-blue-btn{height:40px;padding:10px 24px !important;border:none !important;background:rgba(28,88,217,.08) !important;color:#1c58d9 !important;font-weight:700}.admin-console__banner_section{margin-bottom:20px}.current-plan-legend{margin:10px 0 20px 0;color:#3db887;font-size:14px;font-style:normal;font-weight:600;line-height:14px}.current-plan-legend i{margin-right:5px;margin-left:-5px}
.OpenIdConvert{display:grid;padding:0;border:1px solid rgba(87,158,255,.24);margin-bottom:25px;background-color:rgba(87,158,255,.08);border-radius:4px;font-family:Open Sans;font-style:normal;font-weight:normal;grid-template-columns:auto 1fr}.OpenIdConvert p{margin:0 0 8px}.OpenIdConvert .btn{width:191px;height:32px;margin-right:10px;background:#166de0;border-radius:4px;color:#fff;font-size:12px;font-weight:600;line-height:9px}.OpenIdConvert .btn:focus,.OpenIdConvert .btn:active,.OpenIdConvert .btn:focus:active{border-color:rgba(0,0,0,0);outline:none}.OpenIdConvert .btn-secondary{display:flex;min-width:100px;height:32px;align-items:center;justify-content:center;margin:0 10px 0 0;border-radius:4px;text-decoration:none}.OpenIdConvert .btn-secondary:hover{background-color:#166de0;color:#fff}.OpenIdConvert_actionWrapper{z-index:100;display:flex;width:100%;height:40px;-webkit-flex:0 0 60px;flex:0 0 60px;align-items:center;padding:4 0 4px;border-top:1px solid alpha-color(rgb(0, 0, 0), 0.1)}.OpenIdConvert_copyWrapper{padding:16px 16px 16px 12px}.OpenIdConvert_imageWrapper{padding:16px 0 0 16px}.OpenIdConvert_image{height:18px}.OpenIdConvert__heading{padding-bottom:8px;font-size:14px;font-weight:600;line-height:20px}
.LogTable{overflow:auto}.LogTable .DataGrid .DataGrid_row{min-height:40px;padding-left:16px;cursor:pointer}.LogTable .DataGrid .DataGrid_cell>.timestamp{display:flex;width:100%;align-items:center;cursor:pointer}.LogTable .btn-inverted{border:2px solid var(--denim-button-bg);background:rgba(0,0,0,0);border-radius:4px;color:var(--denim-button-bg);font-weight:bold;line-height:12px}.LogTable .btn-dangerous{border:2px solid var(--dnd-indicator);background:rgba(0,0,0,0);border-radius:4px;color:var(--dnd-indicator);font-weight:bold;line-height:16px}
#SystemRoles{margin-top:0}#SystemRoles .SystemRoles .DataGrid .DataGrid_row{min-height:40px;padding-left:16px;cursor:pointer}#SystemRoles .SystemRoles .DataGrid .DataGrid_cell .SystemRoles_editRow{padding-right:20px}
#SystemRolePermissions{margin-top:0}.SystemRolePermissions{padding:2rem 2rem 2rem 2rem;background:#f5f5f5;color:rgba(var(--sys-center-channel-color-rgb), 0.87)}.SystemRolePermissions .PermissionRow:nth-child(even){background:rgba(255,255,255,.5)}.SystemRolePermissions .PermissionRow .PermissionSection{display:flex;height:auto;flex-direction:row}.SystemRolePermissions .PermissionRow .PermissionSection .PermissionSectionText{display:flex;flex-direction:column;flex-grow:3;align-content:flex-start;padding:14px 16px;margin-top:10px}.SystemRolePermissions .PermissionRow .PermissionSection .PermissionSectionText .PermissionSectionText_title{color:rgba(var(--sys-center-channel-color-rgb), 0.87);font-size:14px;font-weight:600}.SystemRolePermissions .PermissionRow .PermissionSection .PermissionSectionText .PermissionSectionText_description{font-size:12px}.SystemRolePermissions .PermissionRow .PermissionSection .PermissionSectionDropdown{padding:0 16px;margin:auto}.SystemRolePermissions .PermissionRow .PermissionSection .PermissionSectionDropdown .Menu__content{min-width:256px}.SystemRolePermissions .PermissionRow .PermissionSection .PermissionSectionDropdown .MenuWrapper{box-sizing:border-box;background:rgba(var(--sys-center-channel-color-rgb), 0.04);border-radius:4px}.SystemRolePermissions .PermissionRow .PermissionSection .PermissionSectionDropdown .MenuWrapper .PermissionSectionDropdownButton{display:flex;width:132px;height:32px;box-sizing:border-box;justify-content:space-between;padding:1px 0 1px 4px;border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.16);background:var(--sys-center-channel-bg);border-radius:4px;color:var(--sys-center-channel-color);font-size:12px;font-style:normal;font-weight:normal;line-height:28px}.SystemRolePermissions .PermissionRow .PermissionSection .PermissionSectionDropdown .MenuWrapper .PermissionSectionDropdownButton:hover{border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.48)}.SystemRolePermissions .PermissionRow .PermissionSection .PermissionSectionDropdown .MenuWrapper .PermissionSectionDropdownButton .PermissionSectionDropdownButton_text{max-width:230px;flex-grow:3;padding-left:8px;overflow-x:hidden;text-align:left;text-overflow:ellipsis}.SystemRolePermissions .PermissionRow .PermissionSection .PermissionSectionDropdown .MenuWrapper .PermissionSectionDropdownButton .PermissionSectionDropdownButton_more{margin-right:8px;color:rgba(var(--sys-center-channel-color-rgb), 0.6)}.SystemRolePermissions .PermissionRow .PermissionSection .PermissionSectionDropdown .MenuWrapper .PermissionSectionDropdownButton .PermissionSectionDropdownButton_icon{min-width:32px;height:31px;border-left:1px solid rgba(var(--sys-center-channel-color-rgb), 0.16);margin-top:-1px}.SystemRolePermissions .PermissionRow .PermissionSection .PermissionSectionDropdown .MenuWrapper .PermissionSectionDropdownButton .PermissionSectionDropdownButton_icon .Icon{display:flex;width:14px;height:14px;padding-top:8px;margin-right:0;margin-left:6px}.SystemRolePermissions .PermissionRow .PermissionSection .PermissionSectionDropdown .MenuWrapper[disabled]{opacity:1}.SystemRolePermissions .PermissionRow .PermissionSection .PermissionSectionDropdown .MenuWrapper[disabled] .PermissionSectionDropdownButton{border-color:rgba(var(--sys-center-channel-color-rgb), 0.16);background:rgba(var(--sys-center-channel-color-rgb), 0.08);color:var(--sys-center-channel-color)}.SystemRolePermissions .PermissionRow .PermissionSection .PermissionSectionDropdown .PermissionSectionDropdownOptions_description{padding-bottom:4px;line-height:16px}.SystemRolePermissions .PermissionRow .PermissionSubsectionsToggle{margin:0;line-height:16px}.SystemRolePermissions .PermissionRow .PermissionSubsectionsToggle button{font-size:12px}.SystemRolePermissions .PermissionRow .PermissionSubsections{padding-left:16px;border-left:1px solid rgba(var(--sys-center-channel-color-rgb), 0.16);margin:0 0 14px 16px}.SystemRolePermissions .PermissionRow .PermissionSubsections .PermissionSection{height:auto;padding:4px 0}.SystemRolePermissions .PermissionRow .PermissionSubsections .PermissionSection .PermissionSectionText{padding:0;margin:auto}.SystemRolePermissions .PermissionRow .PermissionSubsections .PermissionSection .PermissionSectionText .PermissionSectionText_title{font-size:12px;font-weight:400}.SystemRolePermissions .PermissionRow .PermissionSubsections .PermissionSection .PermissionSection_description{margin:0;font-size:10px;font-weight:600;line-height:15px}.SystemRolePermissions .PermissionRow .PermissionSubsections .PermissionSection .PermissionSection_description span{padding:0 4px;background:rgba(var(--sys-center-channel-color-rgb), 0.08);border-radius:2px}.SystemRolePermissions .PermissionRow .PermissionSubsections .PermissionSection .PermissionSectionDropdown{padding:0 16px;margin:0}.SystemRolePermissions .PermissionRow .PermissionSubsections .PermissionSection:last-of-type{padding-bottom:0}.SystemRolePermissions .PermissionSectionDropdownOptions .PermissionSectionDropdownOptions_label{color:var(--sys-center-channel-color);font-size:14px}.SystemRolePermissions .PermissionSectionDropdownOptions .PermissionSectionDropdownOptions_description{color:rgba(var(--sys-center-channel-color-rgb), 0.56);font-size:12px}.SystemRolePermissionsList{margin-top:12px}.SystemRolePermissionsList li:not(:last-child){margin-bottom:8px}
.AdminButtonOutline.btn.admin-btn-default{border:solid 1px #165dba !important;margin-right:8px;background-color:rgba(0,0,0,0) !important;color:#165dba}.AdminButtonOutline.btn.admin-btn-default:hover,.AdminButtonOutline.btn.admin-btn-default:active,.AdminButtonOutline.btn.admin-btn-default:focus,.AdminButtonOutline.btn.admin-btn-default:active:focus{color:#165dba}
.AdminUserCard{padding:0;margin:2em 0 1em;border-radius:2px;box-shadow:0 1px 2px 0 rgba(0,0,0,.5)}.AdminUserCard__header{display:flex;height:92px;flex-direction:row;align-items:flex-start;padding:30px 20px 12px 30px;background-color:#295eb9}.AdminUserCard__header .Avatar.Avatar-xxl{border:solid 2px #fff}.AdminUserCard__body{padding:12px 20px 20px 178px;background-color:#fff}.AdminUserCard__footer{padding:20px;border-top:solid 1px rgba(0,0,0,.2);background-color:#fff}.AdminUserCard__user-info{align-self:flex-end;padding:0;margin-left:20px;color:#fff;font-size:20px;font-weight:normal}.AdminUserCard__user-nickname{opacity:.5}.AdminUserCard__user-id{align-self:flex-end;margin-left:auto;color:#fff;font-size:12px;opacity:.5}
.AbstractList{padding:1rem 2rem 2rem 2rem;transition:all .4s ease-in-out 0s}.AbstractList .AbstractList__header{display:flex;flex-direction:row;padding:.5em 0;border-bottom:solid 1px rgba(0,0,0,.1);font-size:1.1em;font-weight:bold}.AbstractList .AbstractList__header .AbstractList__header-label{display:inline-block}.AbstractList .AbstractList__body{background:#f5f5f5}.AbstractList .AbstractList__body .AbstractList__loading{padding:40px;text-align:center}.AbstractList .AbstractList__body .AbstractList__empty{margin-top:1rem;background:rgba(255,255,255,.5);color:rgba(0,0,0,.3);font-size:1.6rem;text-align:center}.AbstractList .AbstractList__body .AbstractList__empty span{display:inline-block;width:100%;height:100%;padding-top:20px;padding-bottom:20px}.AbstractList .AbstractList__footer{display:flex;height:auto;align-items:center;justify-content:flex-end;padding:5px;border-top:solid 1px rgba(0,0,0,.1);background:#fff}.AbstractList .AbstractList__footer .btn-tertiary{color:rgba(0,0,0,.5)}.AbstractList .AbstractList__footer .btn-tertiary.disabled{opacity:.5}.AbstractList .AbstractList__footer .counter{margin-bottom:2px;color:rgba(0,0,0,.5);font-size:1.1em}
.d-flex{display:-webkit-box !important;display:-ms-flexbox !important;display:flex !important}.flex-col{flex-direction:column}.flex-1{flex:1}.align-items-center{align-items:center !important;-webkit-box-align:center !important;-ms-flex-align:center !important}.col{max-width:100%;flex-basis:0;flex-grow:1;-ms-flex-positive:1;-ms-flex-preferred-size:0}.flex-auto{flex:0 0 auto}.flex-wrap{flex-wrap:wrap}@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}@keyframes spin{from{transform:scale(1) rotate(0deg)}to{transform:scale(1) rotate(360deg)}}@keyframes highlight{from{background:rgba(255,255,0,.5)}to{background:none}}@keyframes fadeInOpacity{0%{opacity:0}100%{opacity:1}}.pt-0{padding-top:0px !important}.pb-0{padding-bottom:0px !important}.pl-0{padding-left:0px !important}.pr-0{padding-right:0px !important}.mt-0{margin-top:0px !important}.mb-0{margin-bottom:0px !important}.ml-0{margin-left:0px !important}.mr-0{margin-right:0px !important}.m-0{margin:0px !important}.p-0{padding:0px !important}.px-0{padding:0 0px 0 0px !important}.py-0{padding:0px 0 0px 0 !important}.h-0{height:0px !important}.pt-1{padding-top:4px !important}.pb-1{padding-bottom:4px !important}.pl-1{padding-left:4px !important}.pr-1{padding-right:4px !important}.mt-1{margin-top:4px !important}.mb-1{margin-bottom:4px !important}.ml-1{margin-left:4px !important}.mr-1{margin-right:4px !important}.m-1{margin:4px !important}.p-1{padding:4px !important}.px-1{padding:0 4px 0 4px !important}.py-1{padding:4px 0 4px 0 !important}.h-1{height:4px !important}.pt-2{padding-top:8px !important}.pb-2{padding-bottom:8px !important}.pl-2{padding-left:8px !important}.pr-2{padding-right:8px !important}.mt-2{margin-top:8px !important}.mb-2{margin-bottom:8px !important}.ml-2{margin-left:8px !important}.mr-2{margin-right:8px !important}.m-2{margin:8px !important}.p-2{padding:8px !important}.px-2{padding:0 8px 0 8px !important}.py-2{padding:8px 0 8px 0 !important}.h-2{height:8px !important}.pt-3{padding-top:12px !important}.pb-3{padding-bottom:12px !important}.pl-3{padding-left:12px !important}.pr-3{padding-right:12px !important}.mt-3{margin-top:12px !important}.mb-3{margin-bottom:12px !important}.ml-3{margin-left:12px !important}.mr-3{margin-right:12px !important}.m-3{margin:12px !important}.p-3{padding:12px !important}.px-3{padding:0 12px 0 12px !important}.py-3{padding:12px 0 12px 0 !important}.h-3{height:12px !important}.pt-4{padding-top:16px !important}.pb-4{padding-bottom:16px !important}.pl-4{padding-left:16px !important}.pr-4{padding-right:16px !important}.mt-4{margin-top:16px !important}.mb-4{margin-bottom:16px !important}.ml-4{margin-left:16px !important}.mr-4{margin-right:16px !important}.m-4{margin:16px !important}.p-4{padding:16px !important}.px-4{padding:0 16px 0 16px !important}.py-4{padding:16px 0 16px 0 !important}.h-4{height:16px !important}.pt-5{padding-top:20px !important}.pb-5{padding-bottom:20px !important}.pl-5{padding-left:20px !important}.pr-5{padding-right:20px !important}.mt-5{margin-top:20px !important}.mb-5{margin-bottom:20px !important}.ml-5{margin-left:20px !important}.mr-5{margin-right:20px !important}.m-5{margin:20px !important}.p-5{padding:20px !important}.px-5{padding:0 20px 0 20px !important}.py-5{padding:20px 0 20px 0 !important}.h-5{height:20px !important}.pt-6{padding-top:24px !important}.pb-6{padding-bottom:24px !important}.pl-6{padding-left:24px !important}.pr-6{padding-right:24px !important}.mt-6{margin-top:24px !important}.mb-6{margin-bottom:24px !important}.ml-6{margin-left:24px !important}.mr-6{margin-right:24px !important}.m-6{margin:24px !important}.p-6{padding:24px !important}.px-6{padding:0 24px 0 24px !important}.py-6{padding:24px 0 24px 0 !important}.h-6{height:24px !important}.pt-7{padding-top:28px !important}.pb-7{padding-bottom:28px !important}.pl-7{padding-left:28px !important}.pr-7{padding-right:28px !important}.mt-7{margin-top:28px !important}.mb-7{margin-bottom:28px !important}.ml-7{margin-left:28px !important}.mr-7{margin-right:28px !important}.m-7{margin:28px !important}.p-7{padding:28px !important}.px-7{padding:0 28px 0 28px !important}.py-7{padding:28px 0 28px 0 !important}.h-7{height:28px !important}.pt-8{padding-top:32px !important}.pb-8{padding-bottom:32px !important}.pl-8{padding-left:32px !important}.pr-8{padding-right:32px !important}.mt-8{margin-top:32px !important}.mb-8{margin-bottom:32px !important}.ml-8{margin-left:32px !important}.mr-8{margin-right:32px !important}.m-8{margin:32px !important}.p-8{padding:32px !important}.px-8{padding:0 32px 0 32px !important}.py-8{padding:32px 0 32px 0 !important}.h-8{height:32px !important}.pt-9{padding-top:36px !important}.pb-9{padding-bottom:36px !important}.pl-9{padding-left:36px !important}.pr-9{padding-right:36px !important}.mt-9{margin-top:36px !important}.mb-9{margin-bottom:36px !important}.ml-9{margin-left:36px !important}.mr-9{margin-right:36px !important}.m-9{margin:36px !important}.p-9{padding:36px !important}.px-9{padding:0 36px 0 36px !important}.py-9{padding:36px 0 36px 0 !important}.h-9{height:36px !important}.pt-10{padding-top:40px !important}.pb-10{padding-bottom:40px !important}.pl-10{padding-left:40px !important}.pr-10{padding-right:40px !important}.mt-10{margin-top:40px !important}.mb-10{margin-bottom:40px !important}.ml-10{margin-left:40px !important}.mr-10{margin-right:40px !important}.m-10{margin:40px !important}.p-10{padding:40px !important}.px-10{padding:0 40px 0 40px !important}.py-10{padding:40px 0 40px 0 !important}.h-10{height:40px !important}.pt-11{padding-top:44px !important}.pb-11{padding-bottom:44px !important}.pl-11{padding-left:44px !important}.pr-11{padding-right:44px !important}.mt-11{margin-top:44px !important}.mb-11{margin-bottom:44px !important}.ml-11{margin-left:44px !important}.mr-11{margin-right:44px !important}.m-11{margin:44px !important}.p-11{padding:44px !important}.px-11{padding:0 44px 0 44px !important}.py-11{padding:44px 0 44px 0 !important}.h-11{height:44px !important}.pt-12{padding-top:48px !important}.pb-12{padding-bottom:48px !important}.pl-12{padding-left:48px !important}.pr-12{padding-right:48px !important}.mt-12{margin-top:48px !important}.mb-12{margin-bottom:48px !important}.ml-12{margin-left:48px !important}.mr-12{margin-right:48px !important}.m-12{margin:48px !important}.p-12{padding:48px !important}.px-12{padding:0 48px 0 48px !important}.py-12{padding:48px 0 48px 0 !important}.h-12{height:48px !important}.pt-13{padding-top:52px !important}.pb-13{padding-bottom:52px !important}.pl-13{padding-left:52px !important}.pr-13{padding-right:52px !important}.mt-13{margin-top:52px !important}.mb-13{margin-bottom:52px !important}.ml-13{margin-left:52px !important}.mr-13{margin-right:52px !important}.m-13{margin:52px !important}.p-13{padding:52px !important}.px-13{padding:0 52px 0 52px !important}.py-13{padding:52px 0 52px 0 !important}.h-13{height:52px !important}.pt-14{padding-top:56px !important}.pb-14{padding-bottom:56px !important}.pl-14{padding-left:56px !important}.pr-14{padding-right:56px !important}.mt-14{margin-top:56px !important}.mb-14{margin-bottom:56px !important}.ml-14{margin-left:56px !important}.mr-14{margin-right:56px !important}.m-14{margin:56px !important}.p-14{padding:56px !important}.px-14{padding:0 56px 0 56px !important}.py-14{padding:56px 0 56px 0 !important}.h-14{height:56px !important}.pt-15{padding-top:60px !important}.pb-15{padding-bottom:60px !important}.pl-15{padding-left:60px !important}.pr-15{padding-right:60px !important}.mt-15{margin-top:60px !important}.mb-15{margin-bottom:60px !important}.ml-15{margin-left:60px !important}.mr-15{margin-right:60px !important}.m-15{margin:60px !important}.p-15{padding:60px !important}.px-15{padding:0 60px 0 60px !important}.py-15{padding:60px 0 60px 0 !important}.h-15{height:60px !important}.pt-16{padding-top:64px !important}.pb-16{padding-bottom:64px !important}.pl-16{padding-left:64px !important}.pr-16{padding-right:64px !important}.mt-16{margin-top:64px !important}.mb-16{margin-bottom:64px !important}.ml-16{margin-left:64px !important}.mr-16{margin-right:64px !important}.m-16{margin:64px !important}.p-16{padding:64px !important}.px-16{padding:0 64px 0 64px !important}.py-16{padding:64px 0 64px 0 !important}.h-16{height:64px !important}.pt-17{padding-top:68px !important}.pb-17{padding-bottom:68px !important}.pl-17{padding-left:68px !important}.pr-17{padding-right:68px !important}.mt-17{margin-top:68px !important}.mb-17{margin-bottom:68px !important}.ml-17{margin-left:68px !important}.mr-17{margin-right:68px !important}.m-17{margin:68px !important}.p-17{padding:68px !important}.px-17{padding:0 68px 0 68px !important}.py-17{padding:68px 0 68px 0 !important}.h-17{height:68px !important}.pt-18{padding-top:72px !important}.pb-18{padding-bottom:72px !important}.pl-18{padding-left:72px !important}.pr-18{padding-right:72px !important}.mt-18{margin-top:72px !important}.mb-18{margin-bottom:72px !important}.ml-18{margin-left:72px !important}.mr-18{margin-right:72px !important}.m-18{margin:72px !important}.p-18{padding:72px !important}.px-18{padding:0 72px 0 72px !important}.py-18{padding:72px 0 72px 0 !important}.h-18{height:72px !important}.pt-19{padding-top:76px !important}.pb-19{padding-bottom:76px !important}.pl-19{padding-left:76px !important}.pr-19{padding-right:76px !important}.mt-19{margin-top:76px !important}.mb-19{margin-bottom:76px !important}.ml-19{margin-left:76px !important}.mr-19{margin-right:76px !important}.m-19{margin:76px !important}.p-19{padding:76px !important}.px-19{padding:0 76px 0 76px !important}.py-19{padding:76px 0 76px 0 !important}.h-19{height:76px !important}.pt-20{padding-top:80px !important}.pb-20{padding-bottom:80px !important}.pl-20{padding-left:80px !important}.pr-20{padding-right:80px !important}.mt-20{margin-top:80px !important}.mb-20{margin-bottom:80px !important}.ml-20{margin-left:80px !important}.mr-20{margin-right:80px !important}.m-20{margin:80px !important}.p-20{padding:80px !important}.px-20{padding:0 80px 0 80px !important}.py-20{padding:80px 0 80px 0 !important}.h-20{height:80px !important}.d-block{display:block}.w-full{width:100%}.a11y--focused{border-radius:4px;box-shadow:0 0 1px 3px rgba(var(--link-color-rgb), 0.5),0 0 0 1px var(--link-color)}.pos-relative{position:relative}.hidden-label{position:absolute;overflow:hidden;width:1px;height:1px;padding:0;border:0;margin:-1px}.overflow--visible{overflow:visible}.bg--white{background:var(--center-channel-bg)}.TeamRow:nth-child(odd){background:rgba(255,255,255,.5)}.TeamRow__row{display:flex;height:80px;flex-direction:row;align-items:center;border:2px solid rgba(0,0,0,0)}.TeamRow__row .TeamRow__team-name{display:inline-block;min-width:300px;flex-grow:3}.TeamRow__row .TeamRow__team-name .TeamIcon{margin-right:0}.TeamRow__row .TeamRow__team-name .TeamRow__team-description{min-width:276px;max-width:400px}.SystemUserDetail .TeamRow__col-description{min-width:276px;max-width:400px}.TeamRow__row .TeamRow__description{display:flex;overflow:hidden;width:150px;max-width:400px;height:100%;align-items:center}.TeamRow__row .TeamRow__description.adjusted{width:120px}.TeamRow__row .TeamRow__description i{margin-right:5px}.TeamRow__row .TeamRow__description>a{padding:3px 5px;color:#000;text-decoration:none}.TeamRow__row .TeamRow__description>a:hover{background-color:rgba(0,0,0,.15);border-radius:3px}.TeamRow__row .TeamRow__description>a.warning{color:#d64946}.TeamRow__row .TeamRow__actions{display:flex;width:150px;max-width:400px;height:100%;align-items:center;justify-content:flex-end;padding-right:15px}.TeamRow__row .TeamIcon__content{opacity:1}
.SystemUserDetail__field-label{display:block;margin-top:12px;margin-bottom:4px;font-size:12px;font-weight:bold}.SystemUserDetail__input{display:inline-block;max-width:320px;height:40px}.SystemUserDetail .add-team-button{position:relative;margin-left:10px}.SystemUserDetail .team-btn__content{opacity:1}.SystemUserDetail__field-text{vertical-align:middle}.SystemUserDetail__field-icon{display:inline-block;width:16px;height:16px;margin:0 8px 0 0;fill:rgba(61,60,64,.6);vertical-align:middle}.SystemUserDetail__error{padding-top:8px;padding-left:15px}.SystemUserDetail__actions-menu-icon svg{width:18px;color:#333}.SystemUserDetail .MenuItem .SystemUserDetail__action-remove-team{color:#8b0008}
.ChannelsList .DataGrid .DataGrid_row{min-height:40px;padding-left:16px;cursor:pointer}.ChannelsList .DataGrid .DataGrid_cell .TeamList_editRow{padding-right:20px}.ChannelsList .DataGrid .DataGrid_cell .TeamList_channelDisplayName{color:#333;font-weight:600;opacity:.8}.ChannelsList .DataGrid .DataGrid_cell .channel-icon{display:inline-flex;width:16px;justify-content:center;margin-right:10px;font-size:120%;opacity:.8}.ChannelsList .DataGrid .DataGrid_cell .shared-channel-icon{color:#000}.ChannelsList .DataGrid .DataGrid_cell .row-content{display:flex;align-items:center}
.MemberListGroup .DataGrid{display:flex;width:100%;height:calc(90vh - 120px);flex-direction:column;padding:0}.MemberListGroup .DataGrid .DataGrid_rows{height:1px;flex-grow:500;overflow-y:scroll}.MemberListGroup .DataGrid .DataGrid_empty{margin:auto}
.UserGrid_nameRow{display:flex;height:80px}.UserGrid_nameRow .UserGrid_name{display:flex;overflow:hidden;flex-direction:column;flex-grow:1;flex-shrink:1;align-self:center;padding-left:10px;text-overflow:ellipsis}.UserGrid_nameRow .UserGrid_name span{overflow:hidden;text-overflow:ellipsis}.UserGrid_removeRow{padding-right:20px}
.AdminChannelDetails .channel-team{margin-top:12px}.AdminChannelDetails .channel-organizations{margin-top:12px}.AdminChannelDetails .channel-organizations .shared-channel-icon{width:16px;height:16px;margin-right:4px;color:rgba(61,60,64,.72);font-size:16px;line-height:16px}.AdminChannelDetails .channel-organizations .shared-channel-icon::before{margin:0}
.UsersToRemove .DataGrid{display:flex;width:100%;height:calc(90vh - 190px);flex-direction:column;padding:0}.UsersToRemove .DataGrid .DataGrid_rows{height:1px;flex-grow:500;overflow-y:scroll}.UsersToRemove .DataGrid .DataGrid_empty{margin:auto}.UsersToRemove .UsersToRemoveGroups a{color:var(--sys-center-channel-color);text-decoration:none}.UsersToRemove .UsersToRemoveGroups a:hover{text-decoration:underline}
.TeamsList .DataGrid .DataGrid_row{cursor:pointer}.TeamsList .DataGrid .DataGrid_cell .TeamList_nameColumn{display:flex;height:80px;align-items:center}.TeamsList .DataGrid .DataGrid_cell .TeamList_nameColumn .TeamList_nameText{overflow:hidden;padding-right:40px;opacity:.8}.TeamsList .DataGrid .DataGrid_cell .TeamList_nameColumn .TeamList_nameText .archived-label{color:rgba(var(--center-channel-color-rgb), 0.64)}.TeamsList .DataGrid .DataGrid_cell .TeamList_nameColumn .TeamList__lowerOpacity{opacity:.8}.TeamsList .DataGrid .DataGrid_cell .TeamList_nameColumn .TeamList_descriptionText{overflow:hidden;text-overflow:ellipsis}.TeamsList .DataGrid .DataGrid_cell .TeamList_nameColumn .TeamIcon{margin-right:12px;background:rgba(0,0,0,.12)}.TeamsList .DataGrid .DataGrid_cell .TeamList_managementText{opacity:.65}.TeamsList .DataGrid .DataGrid_cell .TeamList_editText{padding-right:20px}
.cloud-limits-disabled{pointer-events:"none"}.upgrade-options-button{height:38px;padding:9px,16px;margin-left:16px;background:#1c58d9;border-radius:4px;color:#fff;font-weight:600}.disabled-overlay-wrapper{display:inline-block;cursor:not-allowed}
.Accordion{width:100%;padding:0;margin:0;list-style:none}.Accordion .accordion-card{box-sizing:border-box;border:1px solid rgba(var(--center-channel-color-rgb) 0.08);background:var(--center-channel-bg);border-radius:4px;box-shadow:var(--elevation-1)}.Accordion .accordion-card .accordion-card:not(:first-of-type){border-top:0}.Accordion .accordion-card .accordion-card-header{display:flex;width:100%;flex-direction:row;align-items:flex-start;padding:15px 20px;border:0;background-color:var(--center-channel-bg);font-size:18px;font-weight:400}.Accordion .accordion-card .accordion-card-header__icon{width:fit-content;max-width:15%;padding:5px}.Accordion .accordion-card .accordion-card-header__body{display:flex;width:fit-content;max-width:80%;flex-direction:column;padding:5px}.Accordion .accordion-card .accordion-card-header__body__title{width:100%;margin:0}.Accordion .accordion-card .accordion-card-header__body__description{width:100%;margin:0}.Accordion .accordion-card .accordion-card-header__chevron{width:fit-content;max-width:5%;padding:5px;margin-left:auto;opacity:.5}.Accordion .accordion-card.active .accordion-card-header__chevron{transform:rotate(-180deg)}.Accordion .accordion-card .accordion-card-container{overflow:hidden;transition:height .2s ease-in-out}.Accordion .accordion-card .accordion-card-container__content{padding:15px 20px;border-top:1px solid rgba(var(--center-channel-color-rgb) 0.04)}
.error,.WorkspaceOptimizationDashboard button[class*=" StyledChip"].error,.WorkspaceOptimizationDashboard button[class^=StyledChip].error{color:var(--sys-error-text)}.info,.WorkspaceOptimizationDashboard button[class*=" StyledChip"].info,.WorkspaceOptimizationDashboard button[class^=StyledChip].info{color:var(--sys-sidebar-text-active-border)}.warning,.WorkspaceOptimizationDashboard button[class*=" StyledChip"].warning,.WorkspaceOptimizationDashboard button[class^=StyledChip].warning{color:var(--sys-away-indicator-dark)}.ok,.WorkspaceOptimizationDashboard button[class*=" StyledChip"].ok,.WorkspaceOptimizationDashboard button[class^=StyledChip].ok{color:var(--sys-online-indicator)}.scoreGraph,.WorkspaceOptimizationDashboard div.OverallScore__scoreEllipseSvg .successImageScore,.WorkspaceOptimizationDashboard div.OverallScore__scoreEllipseSvg .alertImageScore{display:flex;width:112px;height:112px;align-items:center;justify-content:center;border-radius:50%}.WorkspaceOptimizationDashboard{background-color:#fff}.WorkspaceOptimizationDashboard button[class*=" StyledChip"],.WorkspaceOptimizationDashboard button[class^=StyledChip]{width:120px;height:24px;justify-content:space-around;border:none;margin-right:8px;margin-bottom:0;box-shadow:none;font-size:12px;font-style:normal;font-weight:bold;line-height:16px;text-align:center}.WorkspaceOptimizationDashboard button[class*=" StyledChip"].error,.WorkspaceOptimizationDashboard button[class^=StyledChip].error{background-color:rgba(var(--sys-error-text-color-rgb), 0.16)}.WorkspaceOptimizationDashboard button[class*=" StyledChip"].info,.WorkspaceOptimizationDashboard button[class^=StyledChip].info{background-color:rgba(var(--sys-sidebar-text-active-border-rgb), 0.16)}.WorkspaceOptimizationDashboard button[class*=" StyledChip"].warning,.WorkspaceOptimizationDashboard button[class^=StyledChip].warning{background-color:rgba(var(--sys-away-indicator-rgb), 0.16)}.WorkspaceOptimizationDashboard button[class*=" StyledChip"].ok,.WorkspaceOptimizationDashboard button[class^=StyledChip].ok{background-color:rgba(var(--sys-online-indicator-rgb), 0.16)}.WorkspaceOptimizationDashboard div.OverallScore{display:flex;width:872px;box-sizing:border-box;align-items:center;padding:24px;border:1px solid rgba(var(--sys-denim-center-channel-text-rgb), 0.08) !important;margin-left:4px;background:var(--sys-center-channel-bg);border-radius:4px;box-shadow:var(--elevation-1)}.WorkspaceOptimizationDashboard div.OverallScore__scoreEllipseSvg{display:flex;width:140px;height:140px;align-items:center}.WorkspaceOptimizationDashboard div.OverallScore__scoreEllipseSvg .alertImageScore{background-color:rgba(var(--sys-error-text-color-rgb), 0.3)}.WorkspaceOptimizationDashboard div.OverallScore__scoreEllipseSvg .successImageScore{background-color:rgba(var(--sys-online-indicator-rgb), 0.3)}.WorkspaceOptimizationDashboard div.OverallScore__scoreEllipseSvg .CircularChart .circular-chart{display:block;margin:5px auto}.WorkspaceOptimizationDashboard div.OverallScore__scoreEllipseSvg .CircularChart .circular-chart.warning .circle{stroke:var(--sys-away-indicator)}.WorkspaceOptimizationDashboard div.OverallScore__scoreEllipseSvg .CircularChart .circular-chart.success .circle{stroke:var(--sys-online-indicator)}.WorkspaceOptimizationDashboard div.OverallScore__scoreEllipseSvg .CircularChart .circular-chart.info .circle{stroke:var(--sys-sidebar-text-active-border)}.WorkspaceOptimizationDashboard div.OverallScore__scoreEllipseSvg .CircularChart .circular-chart.error .circle{stroke:var(--sys-error-text)}.WorkspaceOptimizationDashboard div.OverallScore__scoreEllipseSvg .CircularChart .circular-chart .circle{animation:progress 1s ease-out forwards;fill:none;stroke-width:3.55}.WorkspaceOptimizationDashboard div.OverallScore__scoreEllipseSvg .CircularChart .circular-chart .percentageOrNumber{font-family:Metropolis;font-size:.65em;font-weight:550}@keyframes progress{0%{stroke-dasharray:0 100}}.WorkspaceOptimizationDashboard div.OverallScore__content{display:flex;flex-direction:column;margin-left:24px}.WorkspaceOptimizationDashboard div.OverallScore__content__title{margin-bottom:8px;color:var(--sys-denim-center-channel-text);font-size:22px;font-weight:700;line-height:28px}.WorkspaceOptimizationDashboard div.OverallScore__content__description{margin-bottom:24px;color:var(--sys-denim-center-channel-text);font-size:14px;font-style:normal;font-weight:normal;line-height:20px}.WorkspaceOptimizationDashboard div.OverallScore__content__chips{display:flex;flex-direction:row}.WorkspaceOptimizationDashboard div.OverallScore__content__chips button[class*=" StyledChip"],.WorkspaceOptimizationDashboard div.OverallScore__content__chips button[class^=StyledChip]{width:180px;height:32px;margin-right:16px}.WorkspaceOptimizationDashboard ul.Accordion{width:872px;margin-left:4px}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card{box-sizing:border-box;border:1px solid rgba(63,67,80,.08) !important;margin-top:16px;background-color:var(--sys-center-channel-bg)}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-header{max-height:92px;padding:0;background-color:var(--sys-center-channel-bg)}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-header__icon{padding:0;margin:24px 0 24px 24px}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-header__icon div{z-index:1;display:flex;width:44px;height:44px;align-items:center;justify-content:center;background-color:rgba(var(--sys-denim-center-channel-text-rgb), 0.16);border-radius:50%}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-header__icon div.success{background-color:rgba(var(--sys-online-indicator-rgb), 0.16)}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-header__icon div.success svg{opacity:1}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-header__icon div svg{opacity:.56}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-header__body{padding:0;margin:27px 0 26px 16px}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-header__body__title{margin-bottom:5px;color:#1c58d9;font-size:14px;font-weight:600;line-height:14px}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-header__body__description{color:#3d3c40;font-size:14px;font-style:normal;font-weight:normal;line-height:20px}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-header__extraContent{display:flex;flex-direction:row;align-items:flex-end;margin-top:34px;margin-left:auto}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-header__extraContent button[class*=" StyledChip"],.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-header__extraContent button[class^=StyledChip]{margin-right:24px}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-header__chevron{padding:0;margin:30px 30px 30px 0;font-size:24px}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-container__content{padding:16px 24px;border-top:1px solid rgba(63,67,80,.06);background-color:#fff}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-container__content div[class*=" AccordionItem"],.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-container__content div[class^=AccordionItem]{padding:16px 0}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-container__content div[class*=" AccordionItem"] h5,.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-container__content div[class^=AccordionItem] h5{margin-top:0;margin-bottom:4px}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-container__content div[class*=" AccordionItem"] i,.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-container__content div[class^=AccordionItem] i{margin-left:-5px;font-size:20px}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-container__content div[class*=" AccordionItem"] i.warning,.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-container__content div[class^=AccordionItem] i.warning{color:var(--sys-away-indicator)}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-container .ctaButtons{display:flex;justify-content:flex-start;margin:15px 0 0 0}.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-container .ctaButtons a,.WorkspaceOptimizationDashboard ul.Accordion li.accordion-card .accordion-card-container .ctaButtons button{max-height:32px;padding:5px 20px !important;margin-top:0;margin-right:10px;border-radius:4px !important;font-weight:600}
.CircularChart .circular-chart{display:block;margin:5px auto}.CircularChart .circular-chart.warning .circle{stroke:var(--away-indicator)}.CircularChart .circular-chart.success .circle{stroke:var(--denim-status-online)}.CircularChart .circular-chart.info .circle{stroke:var(--sidebar-text-active-border)}.CircularChart .circular-chart.error .circle{stroke:var(--error-text)}.CircularChart .circular-chart .circle-bg{fill:none;stroke:rgba(0,0,0,0);stroke-width:4.2}.CircularChart .circular-chart .circle{animation:progress 1s ease-out forwards;fill:none;stroke-width:3.2}@keyframes progress{0%{stroke-dasharray:0 100}}.CircularChart .percentageOrNumber{fill:var(--sys-center-channel-color);font-family:sans-serif;font-size:.5em;text-anchor:middle}
.CommercialSupportModal{padding:20px 20px}.CommercialSupportModal .DownloadSupportPacket{margin-top:20px}.CommercialSupportModal .AlertBanner{margin-top:20px}

/*# sourceMappingURL=4217.b02454b009c376f7a9a1.css.map*/